<?php

use \Elementor\Widget_Base;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Typography;
use \Elementor\Repeater;
use \Elementor\Utils;
use \Elementor\Group_Control_Background;
use \Elementor\Group_Control_Text_Shadow;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
/**
 *
 * Header 2 Widget . 
 *
 */
class Poolax_Header2 extends Widget_Base {

	public function get_name() {
		return 'poolaxheader2';
	}
	public function get_title() {
		return __( 'Header 2', 'poolax' );
	}
	public function get_icon() {
		return 'th-icon';
    }
	public function get_categories() {
		return [ 'poolax_header_elements' ];
	}

	protected function register_controls() {

		$this->start_controls_section(
			'layout_section',
			[
				'label' 	=> __( 'Header 2', 'poolax' ),
				'tab' 		=> Controls_Manager::TAB_CONTENT,
			]
        );

        $this->add_control(
			'layout_style',
			[
				'label' 	=> __( 'Layout Style', 'poolax' ),
				'type' 		=> Controls_Manager::SELECT,
				'options' 	=> [
					'1' => __( 'Style One', 'poolax' ),
					'2' => __( 'Style Two', 'poolax' ),
				],
				'default' => '1',
			]
        );

		$this->add_control(
			'logo_image',

			[
				'label' 		=> __( 'Upload Logo', 'poolax' ),
				'type' 			=> Controls_Manager::MEDIA,
			]
		);				

		$menus = $this->poolax_menu_select();

		if( !empty( $menus ) ){
	        $this->add_control(
				'poolax_menu_select',
				[
					'label'     	=> __( 'Select Poolax Menu', 'poolax' ),
					'type'      	=> Controls_Manager::SELECT,
					'options'   	=> $menus,
					'description' 	=> sprintf( __( 'Go to the <a href="%s" target="_blank">Menus screen</a> to manage your menus.', 'poolax' ), admin_url( 'nav-menus.php' ) ),
				]
			);
		}else {
			$this->add_control(
				'no_menu',
				[
					'type' 				=> Controls_Manager::RAW_HTML,
					'raw' 				=> '<strong>' . __( 'There are no menus in your site.', 'poolax' ) . '</strong><br>' . sprintf( __( 'Go to the <a href="%s" target="_blank">Menus screen</a> to create one.', 'poolax' ), admin_url( 'nav-menus.php?action=edit&menu=0' ) ),
					'separator' 		=> 'after',
					'content_classes' 	=> 'elementor-panel-alert elementor-panel-alert-info',
				]
			);
		}

		$this->add_control(
			'show_search_btn',
			[
				'label' 		=> __( 'Show Search Button?', 'poolax' ),
				'type' 			=> Controls_Manager::SWITCHER,
				'label_on' 		=> __( 'Show', 'poolax' ),
				'label_off' 	=> __( 'Hide', 'poolax' ),
				'return_value' 	=> 'yes',
				'default' 		=> 'yes',
			]
		);		

		$this->add_control(
			'show_offcanvas_btn',
			[
				'label' 		=> __( 'Show Offcanvas Button?', 'poolax' ),
				'type' 			=> Controls_Manager::SWITCHER,
				'label_on' 		=> __( 'Show', 'poolax' ),
				'label_off' 	=> __( 'Hide', 'poolax' ),
				'return_value' 	=> 'yes',
				'default' 		=> 'yes',
			]
		);

		$this->add_control(
			'button_text',
			[
				'label' 		=> __( 'Button Text', 'poolax' ),
				'type' 			=> Controls_Manager::TEXT,
				'label_block' 	=> true,
				'default' 	=> __( 'REGISTER NOW', 'poolax' ),
			]
		);

		$this->add_control(
			'button_url',
			[
				'label' 		=> esc_html__( 'Button Link', 'poolax' ),
				'type' 			=> Controls_Manager::URL,
				'placeholder' 	=> esc_html__( 'https://your-link.com', 'poolax' ),
				'show_external' => true,
				'default' 		=> [
					'url' 			=> '#',
					'is_external' 	=> false,
					'nofollow' 		=> false,
				],
			]
		);

        $this->end_controls_section();

		//---------------------------------------
			//Style Section Start
		//---------------------------------------

		//-------General Style-------
		 $this->start_controls_section(
			'general_styling',
			[
				'label'     => __( 'Background Styling', 'poolax' ),
				'tab'       => Controls_Manager::TAB_STYLE,
			]
        );
   
		poolax_color_fields($this, 'menu_bg', 'Menu BG', 'background', '{{WRAPPER}} .menu-area', ['1', '2']);       
		poolax_color_fields($this, 'menu_bg2', 'Menu BG', 'background', '{{WRAPPER}} .menu-area:after', ['2']);       

		$this->end_controls_section();

		//------Menu Bar Style-------
        $this->start_controls_section(
			'menubar_styling3',
			[
				'label'     => __( 'Menu Styling', 'poolax' ),
				'tab'       => Controls_Manager::TAB_STYLE,
			]
        );

		poolax_color_fields($this, 'menu_color', 'Color', 'color', '{{WRAPPER}} .main-menu>ul>li>a');
		poolax_color_fields($this, 'menu_color2', 'Hover Color', 'color', '{{WRAPPER}} .main-menu>ul>li>a:hover');
		poolax_color_fields($this, 'menu_color3', 'Dropdown Color', 'color', '{{WRAPPER}} .main-menu ul.sub-menu li a');
		poolax_color_fields($this, 'menu_color4', 'Dropdown Hover Color', 'color', '{{WRAPPER}} .main-menu ul.sub-menu li a:hover');
		poolax_color_fields($this, 'menu_color5', 'Menu Icon Color', 'color', '{{WRAPPER}} .main-menu ul.sub-menu li a:before');

		poolax_typography_fields($this, 'menu_font', 'Menu Trpography', '{{WRAPPER}} .main-menu>ul>li>a, {{WRAPPER}} .main-menu ul.sub-menu li a');

		poolax_dimensions_fields($this, 'menu_margin', 'Menu Margin', 'margin', '{{WRAPPER}} .main-menu>ul>li>a');
		poolax_dimensions_fields($this, 'menu_padding', 'Menu Padding', 'padding', '{{WRAPPER}} .main-menu>ul>li>a');

		$this->end_controls_section();

		//------Button Style-------
		poolax_button_style_fields($this, '12', 'Button Styling', '{{WRAPPER}} .th_btn', ['1', '2', '3']);

    }



    public function poolax_menu_select(){
	    $poolax_menu = wp_get_nav_menus();
	    $menu_array  = array();
		$menu_array[''] = __( 'Select A Menu', 'poolax' );
	    foreach( $poolax_menu as $menu ){
	        $menu_array[ $menu->slug ] = $menu->name;
	    }
	    return $menu_array;
	}

	protected function render() {

        $settings = $this->get_settings_for_display();

		global $woocommerce;

        //Menu by menu select
        $poolax_avaiable_menu   = $this->poolax_menu_select();
		if( ! $poolax_avaiable_menu ){
			return;
		}
		$args = [
			'menu' 			=> $settings['poolax_menu_select'],
			'menu_class' 	=> 'poolax-menu',
			'container' 	=> '',
		];

		//Mobile menu, Offcanvas, Search
        echo poolax_mobile_menu();
		echo poolax_header_cart_offcanvas();
		echo poolax_header_offcanvas();
		echo poolax_search_box();

		// Header sub-menu icon / Header Sticky On/Off
		if( class_exists( 'ReduxFramework' ) ){ 
			if(poolax_opt('poolax_menu_icon')){
				$menu_icon = '';
			}else{
				$menu_icon = 'hide-icon';
			}

			if(poolax_opt('poolax_header_sticky')){
                $sticky = '';
            }else{
                $sticky = '-no';
            }
		}

		if( $settings['layout_style'] == '1' ){
			echo '<div class="th-header  header-layout7">';
                echo '<div class="sticky-wrapper'.esc_attr($sticky).'">';
                    echo '<div class="menu-area">';
                        echo '<div class="container th-container">';
                            echo '<div class="row justify-content-between align-items-center">';
                                echo '<div class="col-auto">';
                                    echo '<div class="header-logo">';
                                        echo '<a href="'.esc_url( home_url( '/' ) ).'">';
												echo poolax_img_tag( array(
													'url'   => esc_url( $settings['logo_image']['url']  ),
												));
										echo '</a>';
                                    echo '</div>';
                                echo '</div>';
                                echo '<div class="col-auto">';
                                    echo '<nav class="main-menu d-none d-lg-inline-block '.esc_attr($menu_icon).'">';
										if( ! empty( $settings['poolax_menu_select'] ) ){
											wp_nav_menu( $args );
										}
									echo '</nav>';
                                echo '</div>';
                                echo '<div class="col-auto ml-20">';
                                    echo '<div class="header-button">';
                                        if(!empty( $settings['show_search_btn'])){
                                            echo '<button type="button" class="icon-btn searchBoxToggler"><i class="far fa-search"></i></button>';
                                        }
                                        if(!empty( $settings['show_offcanvas_btn'])){
                                            echo '<a href="#" class="icon-btn sideMenuToggler d-none d-lg-block"><i class="far fa-bars"></i></a>';
                                        }
                                        if(!empty( $settings['button_text'])){
											echo '<a href="'.esc_url($settings['button_url']['url']).'" class="th-btn th_btn radius-none">'.wp_kses_post($settings['button_text']).'</a>';
										}
                                        echo '<button class="icon-btn th-menu-toggle d-inline-block d-lg-none"><i class="far fa-bars"></i></button>';
                                    echo '</div>';
                                echo '</div>';
                            echo '</div>';
                        echo '</div>';
                    echo '</div>';
                echo '</div>';
            echo '</div>';

		}elseif( $settings['layout_style'] == '2' ){
			echo '<div class="th-header header-layout9">';
				echo '<div class="sticky-wrapper'.esc_attr($sticky).'">';
					echo '<div class="menu-area">';
						echo '<div class="container th-container">';
							echo '<div class="row justify-content-between align-items-center">';
								echo '<div class="col-auto">';
									echo '<div class="header-logo">';
										echo '<a href="'.esc_url( home_url( '/' ) ).'">';
												echo poolax_img_tag( array(
													'url'   => esc_url( $settings['logo_image']['url']  ),
												));
										echo '</a>';
									echo '</div>';
								echo '</div>';
								echo '<div class="col-auto">';
									echo '<nav class="main-menu d-none d-lg-inline-block '.esc_attr($menu_icon).'">';
										if( ! empty( $settings['poolax_menu_select'] ) ){
											wp_nav_menu( $args );
										}
									echo '</nav>';
								echo '</div>';
								echo '<div class="col-auto ml-20">';
									echo '<div class="header-button">';
										if(!empty( $settings['show_search_btn'])){
                                            echo '<button type="button" class="icon-btn searchBoxToggler"><i class="far fa-search"></i></button>';
                                        }
										if(!empty( $settings['button_text'])){
											echo '<a href="'.esc_url($settings['button_url']['url']).'" class="th-btn th_btn">'.wp_kses_post($settings['button_text']).'</a>';
										}
										if(!empty( $settings['show_offcanvas_btn'])){
											echo '<a href="#" class="icon-btn sideMenuToggler d-none d-lg-block"><img src="'.POOLAX_ASSETS.'img/bars.svg" alt="'.esc_attr__('Image', 'poolax').'"></a>'; 
										}
										echo '<button class="icon-btn th-menu-toggle d-inline-block d-lg-none"><i class="far fa-bars"></i></button>';
									echo '</div>';
								echo '</div>';
							echo '</div>';
						echo '</div>';
					echo '</div>';
				echo '</div>';
			echo '</div>';

		}


	}
}