<?php
use \Elementor\Widget_Base;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Typography;
use \Elementor\Group_Control_Border;
use \Elementor\Utils;
/**
 *
 * Blog Post Widget .
 *
 */
class poolax_Blog extends Widget_Base {

	public function get_name() {
		return 'poolaxblog';
	}
	public function get_title() {
		return __( 'Blog Post', 'poolax' );
	}
	public function get_icon() {
		return 'th-icon';
    }
	public function get_categories() {
		return [ 'poolax' ];
	}

	protected function register_controls() {

		$this->start_controls_section(
			'blog_post_section',
			[
				'label' => __( 'Blog Post', 'poolax' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
        );

        $this->add_control(
			'layout_style',
			[
				'label' 	=> __( 'Layout Style', 'poolax' ),
				'type' 		=> Controls_Manager::SELECT,
				'default' 	=> '1',
				'options' 	=> [
					'1'  		=> __( 'Style One', 'poolax' ),
					'2' 		=> __( 'Style Two', 'poolax' ),
					'3' 		=> __( 'Style Three', 'poolax' ),
					'4' 		=> __( 'Style Four', 'poolax' ),
					'5' 		=> __( 'Style Five', 'poolax' ),
					'6' 		=> __( 'Style Six', 'poolax' ),
					'7' 		=> __( 'Style Seven', 'poolax' ),
					'8' 		=> __( 'Style Eight', 'poolax' ),
				],
				'separator' => 'after'
			]
		);

        poolax_general_fields($this, 'arrow_id', 'Arrow ID', 'TEXT', 'blogSlide3', ['5']);

        $this->add_control(
			'blog_post_count',
			[
				'label' 	=> __( 'No of Post to show', 'poolax' ),
                'type' 		=> Controls_Manager::NUMBER,
                'min'       => 1,
                'max'       => count( get_posts( array('post_type' => 'post', 'post_status' => 'publish', 'fields' => 'ids', 'posts_per_page' => '-1') ) ),
                'default'  	=> __( '4', 'poolax' )
			]
        );

		$this->add_control(
			'title_count',
			[
				'label' 	=> __( 'Title Length', 'poolax' ),
				'type' 		=> Controls_Manager::TEXT,
				'default'  	=> __( '5', 'poolax' ),
			]
		);

		$this->add_control(
			'excerpt_count',
			[
				'label' 	=> __( 'Excerpt Length', 'poolax' ),
				'type' 		=> Controls_Manager::TEXT,
				'default'  	=> __( '12', 'poolax' ),
                'condition'	=> [
					'layout_style' => ['4', '5'],
				]
			]
		);

        $this->add_control(
			'blog_post_order',
			[
				'label' 	=> __( 'Order', 'poolax' ),
                'type' 		=> Controls_Manager::SELECT,
                'options'   => [
                    'ASC'   	=> __('ASC','poolax'),
                    'DESC'   	=> __('DESC','poolax'),
                ],
                'default'  	=> 'DESC'
			]
        );

        $this->add_control(
			'blog_post_order_by',
			[
				'label' 	=> __( 'Order By', 'poolax' ),
                'type' 		=> Controls_Manager::SELECT,
                'options'   => [
                    'ID'    	=> __( 'ID', 'poolax' ),
                    'author'    => __( 'Author', 'poolax' ),
                    'title'    	=> __( 'Title', 'poolax' ),
                    'date'    	=> __( 'Date', 'poolax' ),
                    'rand'    	=> __( 'Random', 'poolax' ),
                ],
                'default'  	=> 'ID'
			]
        );

        $this->add_control(
			'exclude_cats',
			[
				'label' 		=> __( 'Exclude Categories', 'poolax' ),
                'type' 			=> Controls_Manager::SELECT2,
                'multiple' 		=> true,
				'options' 		=> $this->poolax_get_categories(),
			]
        );

        $this->add_control(
			'exclude_tags',
			[
				'label' 		=> __( 'Exclude Tags', 'poolax' ),
                'type' 			=> Controls_Manager::SELECT2,
                'multiple' 		=> true,
				'options' 		=> $this->poolax_get_tags(),
			]
        );

        $this->add_control(
			'exclude_post_id',
			[
				'label'         => __( 'Exclude Post', 'poolax' ),
                'type'          => Controls_Manager::SELECT2,
                'multiple'      => true,
				'options'       => $this->poolax_post_id(),
			]
        );

        $this->add_control(
			'read_more',
			[
				'label' 	=> __( 'Read More Text', 'poolax' ),
                'type' 		=> Controls_Manager::TEXTAREA,
				'rows'	=> 3,
                'default'  	=> __( 'Read More', 'poolax' ),
			]
        );

        $this->end_controls_section();

		//---------------------------------------
			//Style Section Start
		//---------------------------------------

		//-------Title Style-------
		poolax_common_style_fields( $this, 'title', 'Title', '{{WRAPPER}} .box-title' );
		poolax_common_style_fields( $this, 'desc', 'Description', '{{WRAPPER}} .box-text', ['4', '5'] );
		//------Button Style-------
		poolax_button_style_fields( $this, '10', 'Button Styling', '{{WRAPPER}} .th-btn' );


    }

    public function poolax_get_categories() {
        $cats = get_terms(array(
            'taxonomy' => 'category',
            'hide_empty' => true,
        ));

        $catarr = [];

        foreach( $cats as $singlecat ) {
            $catarr[$singlecat->term_id] = __($singlecat->name,'poolax');
        }

        return $catarr;
    }

    public function poolax_get_tags() {
        $cats = get_terms(array(
            'taxonomy' => 'post_tag',
            'hide_empty' => true,
        ));

        $catarr = [];

        foreach( $cats as $singlecat ) {
            $catarr[$singlecat->term_id] = __($singlecat->name,'poolax');
        }

        return $catarr;
    }

    // Get Specific Post
    public function poolax_post_id(){
        $args = array(
            'post_type'         => 'post',
            'posts_per_page'    => -1,
        );

        $poolax_post = new WP_Query( $args );

        $postarray = [];

        while( $poolax_post->have_posts() ){
            $poolax_post->the_post();
            $postarray[get_the_Id()] = get_the_title();
        }
        wp_reset_postdata();
        return $postarray;
    }

	protected function render() {

        $settings = $this->get_settings_for_display();
        $exclude_post = $settings['exclude_post_id'];

        if( !empty( $settings['exclude_cats'] ) && empty( $settings['exclude_tags'] ) && empty( $settings['exclude_post_id'] ) ) {
            $args = array(
                'post_type'             => 'post',
                'posts_per_page'        => esc_attr( $settings['blog_post_count'] ),
                'order'                 => esc_attr( $settings['blog_post_order'] ),
                'orderby'               => esc_attr( $settings['blog_post_order_by'] ),
                'ignore_sticky_posts'   => true,
                'category__not_in'      => $settings['exclude_cats']
            );
        } elseif( !empty( $settings['exclude_cats'] ) && !empty( $settings['exclude_tags'] ) && empty( $settings['exclude_post_id'] ) ) {
            $args = array(
                'post_type'             => 'post',
                'posts_per_page'        => esc_attr( $settings['blog_post_count'] ),
                'order'                 => esc_attr( $settings['blog_post_order'] ),
                'orderby'               => esc_attr( $settings['blog_post_order_by'] ),
                'ignore_sticky_posts'   => true,
                'category__not_in'      => $settings['exclude_cats'],
                'tag__not_in'           => $settings['exclude_tags']
            );
        }elseif( !empty( $settings['exclude_cats'] ) && !empty( $settings['exclude_tags'] ) && !empty( $settings['exclude_post_id'] ) ) {
            $args = array(
                'post_type'             => 'post',
                'posts_per_page'        => esc_attr( $settings['blog_post_count'] ),
                'order'                 => esc_attr( $settings['blog_post_order'] ),
                'orderby'               => esc_attr( $settings['blog_post_order_by'] ),
                'ignore_sticky_posts'   => true,
                'category__not_in'      => $settings['exclude_cats'],
                'tag__not_in'           => $settings['exclude_tags'],
                'post__not_in'          => $exclude_post
            );
        } elseif( !empty( $settings['exclude_cats'] ) && empty( $settings['exclude_tags'] ) && !empty( $settings['exclude_post_id'] ) ) {
            $args = array(
                'post_type'             => 'post',
                'posts_per_page'        => esc_attr( $settings['blog_post_count'] ),
                'order'                 => esc_attr( $settings['blog_post_order'] ),
                'orderby'               => esc_attr( $settings['blog_post_order_by'] ),
                'ignore_sticky_posts'   => true,
                'category__not_in'      => $settings['exclude_cats'],
                'post__not_in'          => $exclude_post
            );
        } elseif( empty( $settings['exclude_cats'] ) && !empty( $settings['exclude_tags'] ) && !empty( $settings['exclude_post_id'] ) ) {
            $args = array(
                'post_type'             => 'post',
                'posts_per_page'        => esc_attr( $settings['blog_post_count'] ),
                'order'                 => esc_attr( $settings['blog_post_order'] ),
                'orderby'               => esc_attr( $settings['blog_post_order_by'] ),
                'ignore_sticky_posts'   => true,
                'tag__not_in'           => $settings['exclude_tags'],
                'post__not_in'          => $exclude_post
            );
        } elseif( empty( $settings['exclude_cats'] ) && !empty( $settings['exclude_tags'] ) && empty( $settings['exclude_post_id'] ) ) {
            $args = array(
                'post_type'             => 'post',
                'posts_per_page'        => esc_attr( $settings['blog_post_count'] ),
                'order'                 => esc_attr( $settings['blog_post_order'] ),
                'orderby'               => esc_attr( $settings['blog_post_order_by'] ),
                'ignore_sticky_posts'   => true,
                'tag__not_in'           => $settings['exclude_tags'],
            );
        } elseif( empty( $settings['exclude_cats'] ) && empty( $settings['exclude_tags'] ) && !empty( $settings['exclude_post_id'] ) ) {
            $args = array(
                'post_type'             => 'post',
                'posts_per_page'        => esc_attr( $settings['blog_post_count'] ),
                'order'                 => esc_attr( $settings['blog_post_order'] ),
                'orderby'               => esc_attr( $settings['blog_post_order_by'] ),
                'ignore_sticky_posts'   => true,
                'post__not_in'          => $exclude_post
            );
        } else {
            $args = array(
                'post_type'             => 'post',
                'posts_per_page'        => esc_attr( $settings['blog_post_count'] ),
                'order'                 => esc_attr( $settings['blog_post_order'] ),
                'orderby'               => esc_attr( $settings['blog_post_order_by'] ),
                'ignore_sticky_posts'   => true
            );
        }

    $blogpost = new WP_Query( $args );

		if( $settings['layout_style'] == '2' ){
            echo '<div class="row slider-shadow th-carousel" id="blogSlide1" data-slide-show="2" data-lg-slide-show="2" data-md-slide-show="2" data-sm-slide-show="1" data-arrows="true">';
                while( $blogpost->have_posts() ){
                    $blogpost->the_post(); 
                    $categories = get_the_category();
                    echo '<div class="col-md-6 col-xl-4">';
                        echo '<div class="blog-box wow fadeInUp">';
                            echo '<div class="blog-img global-img">';
                                the_post_thumbnail( 'poolax_595X300' );
                            echo '</div>';
                            echo '<div class="blog-box_content">';
                                echo '<div class="blog-wrapper">';
                                    echo '<span class="blog-box_date">'.esc_html( get_the_date( 'd' ) ).'</span>';
                                    echo '<span class="blog-box_month">'.esc_html( get_the_date( 'M, Y' ) ).'</span>';
                                echo '</div>';
                                echo '<div class="blog-meta">';
                                    echo '<a href="'.esc_url( get_author_posts_url( get_the_author_meta('ID') ) ).'"><i class="fa-light fa-user"></i>'.esc_html__('By ', 'poolax') . esc_html( ucwords( get_the_author() ) ).'</a>';
                                    echo '<a href="'.esc_url( get_permalink() ).'"><i class="fa-regular fa-comments"></i> ';
                                        if(get_comments_number() == 1){
                                            echo esc_html__('Comment (', 'poolax'); 
                                        }else{
                                            echo esc_html__('Comments (', 'poolax'); 
                                        }
                                        echo get_comments_number();
                                    echo ')</a>';
                                echo '</div>';
                                echo '<h3 class="box-title"><a href="'.esc_url( get_permalink() ).'">'.esc_html( wp_trim_words( get_the_title( ), $settings['title_count'], '' ) ).'</a></h3>';
                                if(!empty($settings['read_more'])){
                                    echo '<a href="'.esc_url( get_permalink() ).'" class="th-btn border">'.wp_kses_post($settings['read_more']).'</a>';
                                }
                            echo '</div>';
                        echo '</div>';

                    echo '</div>';
                }
            echo '</div>';

		}elseif( $settings['layout_style'] == '3' ){
            echo '<div class="row slider-shadow th-carousel" id="blogSlide3" data-slide-show="3" data-lg-slide-show="2" data-md-slide-show="1" data-sm-slide-show="1" data-arrows="true">';
                while( $blogpost->have_posts() ){
                    $blogpost->the_post(); 
                    $categories = get_the_category();
                    echo '<div class="col-md-6 col-xl-4">';
                        echo '<div class="blog-grid wow fadeInLeft">';
                            echo '<div class="blog-img global-img">';
                                the_post_thumbnail( 'poolax_387X250' );
                                echo '<div class="blog-wrapper">';
                                    echo '<span class="blog-grid_date">'.esc_html( get_the_date( 'd M, Y' ) ).'</span>';
                                echo '</div>';
                            echo '</div>';
                            echo '<div class="blog-grid_content">';
                                echo '<div class="blog-meta">';
                                    echo '<a href="'.esc_url( get_author_posts_url( get_the_author_meta('ID') ) ).'"><i class="fa-light fa-user"></i>'.esc_html__('By ', 'poolax') . esc_html( ucwords( get_the_author() ) ).'</a>';
                                    echo '<a href="'.esc_url( get_permalink() ).'"><i class="fa-regular fa-comments"></i> ';
                                        if(get_comments_number() == 1){
                                            echo esc_html__('Comment (', 'poolax'); 
                                        }else{
                                            echo esc_html__('Comments (', 'poolax'); 
                                        }
                                        echo get_comments_number();
                                    echo ')</a>';
                                echo '</div>';
                                echo '<h3 class="box-title"><a href="'.esc_url( get_permalink() ).'">'.esc_html( wp_trim_words( get_the_title( ), $settings['title_count'], '' ) ).'</a></h3>';
                                if(!empty($settings['read_more'])){
                                    echo '<a href="'.esc_url( get_permalink() ).'" class="th-btn border radius-none">'.wp_kses_post($settings['read_more']).'</a>';
                                }
                            echo '</div>';
                        echo '</div>';
                    echo '</div>';
                }
            echo '</div>';

        }elseif( $settings['layout_style'] == '4' ){
            echo '<div class="row slider-shadow th-carousel" id="blogSlide1" data-slide-show="3" data-lg-slide-show="2" data-md-slide-show="2" data-sm-slide-show="1" data-arrows="true">';
                while( $blogpost->have_posts() ){
                    $blogpost->the_post(); 
                    $categories = get_the_category();
                    echo '<div class="col-md-6 col-xl-4">';
                        echo '<div class="blog-card style2 wow fadeInUp">';
                            echo '<div class="blog-img">';
                                the_post_thumbnail( 'poolax_387X250' );
                                echo '<div class="blog-card_wrapper">';
                                    echo '<span class="blog-card_date">'.esc_html( get_the_date( 'd' ) ).'</span>';
                                    echo '<span class="blog-card_month">'.esc_html( get_the_date( 'M' ) ).'</span>';
                                echo '</div>';
                            echo '</div>';
                            echo '<div class="blog-card-content">';
                                echo '<h3 class="box-title"><a href="'.esc_url( get_permalink() ).'">'.esc_html( wp_trim_words( get_the_title( ), $settings['title_count'], '' ) ).'</a></h3>';

                                echo '<p class="box-text">'.esc_html( wp_trim_words( get_the_content( ), $settings['excerpt_count'], '' ) ).'</p>';
                                if(!empty($settings['read_more'])){
									echo '<a href="'.esc_url( get_permalink() ).'" class="th-btn border">'.wp_kses_post($settings['read_more']).'</a>';
								}
                            echo '</div>';
                        echo '</div>';
                    echo '</div>';
                }
            echo '</div>';

        }elseif( $settings['layout_style'] == '5' ){ 
            echo '<div class="row slider-shadow th-carousel" id="'.esc_attr($settings['arrow_id']).'" data-slide-show="3" data-lg-slide-show="2" data-md-slide-show="2" data-sm-slide-show="1">';
                while( $blogpost->have_posts() ){
                    $blogpost->the_post(); 
                    $categories = get_the_category();
                    echo '<div class="col-md-6 col-xl-4">';
                        echo '<div class="blog-block wow fadeInUp">';
                            echo '<div class="blog-block_img global-img">';
                                the_post_thumbnail( 'poolax_387X250' );
                            echo '</div>';
                            echo '<div class="blog-block_content">';
                                echo '<div class="blog-meta">';
                                    echo '<a href="'.esc_url( get_author_posts_url( get_the_author_meta('ID') ) ).'"><i class="fa-light fa-user"></i>'.esc_html__('By ', 'poolax') . esc_html( ucwords( get_the_author() ) ).'</a>';
                                    echo '<a href="'.esc_url( poolax_blog_date_permalink() ).'"><i class="fa-regular fa-calendar"></i>'.esc_html( get_the_date( ) ).'</a>';
                                echo '</div>';
                                echo '<h3 class="box-title"><a href="'.esc_url( get_permalink() ).'">'.esc_html( wp_trim_words( get_the_title( ), $settings['title_count'], '' ) ).'</a></h3>';
                                echo '<p class="box-text">'.esc_html( wp_trim_words( get_the_content( ), $settings['excerpt_count'], '' ) ).'</p>';
                                if(!empty($settings['read_more'])){
                                    echo '<a href="'.esc_url( get_permalink() ).'" class="th-btn border">'.wp_kses_post($settings['read_more']).'</a>';
                                }
                            echo '</div>';
                        echo '</div>';
                    echo '</div>';
                }
            echo '</div>';

        }elseif( $settings['layout_style'] == '6' ){
            echo '<div class="row slider-shadow th-carousel" id="blogSlide6" data-slide-show="3" data-lg-slide-show="2" data-md-slide-show="1" data-sm-slide-show="1" data-arrows="true">';
                while( $blogpost->have_posts() ){
                    $blogpost->the_post(); 
                    $categories = get_the_category();
                    echo '<div class="col-md-6 col-xl-4">';
                        echo '<div class="blog-grid-2 wow fadeInLeft">';
                            echo '<div class="blog-img global-img">';
                                the_post_thumbnail( 'poolax_387X250' );
                            echo '</div>';
                            echo '<div class="blog-grid-2_content">';
                                echo '<div class="blog-calendar">';
                                    echo '<span class="blog-date">'.esc_html( get_the_date( 'd' ) ).'</span>';
                                    echo '<span class="blog-month">'.esc_html( get_the_date( 'M Y' ) ).'</span>';
                                echo '</div>';
                                echo '<div class="blog-meta">';
                                    echo '<a href="'.esc_url( get_author_posts_url( get_the_author_meta('ID') ) ).'"><i class="fa-regular fa-user"></i>'.esc_html__('By ', 'poolax') . esc_html( ucwords( get_the_author() ) ).'</a>';
                                    echo '<a href="'.esc_url( get_permalink() ).'"><i class="fa-regular fa-comments"></i> ';
                                        if(get_comments_number() == 1){
                                            echo esc_html__('Comment (', 'poolax'); 
                                        }else{
                                            echo esc_html__('Comments (', 'poolax'); 
                                        }
                                        echo get_comments_number();
                                    echo ')</a>';

                                echo '</div>';
                                echo '<h3 class="box-title"><a href="'.esc_url( get_permalink() ).'">'.esc_html( wp_trim_words( get_the_title( ), $settings['title_count'], '' ) ).'</a></h3>';
                                if(!empty($settings['read_more'])){
									echo '<a href="'.esc_url( get_permalink() ).'" class="th-btn border">'.wp_kses_post($settings['read_more']).'</a>';
								}
                            echo '</div>';
                        echo '</div>';
                    echo '</div>';
                }
            echo '</div>';

        }elseif( $settings['layout_style'] == '7' ){
            echo '<div class="row slider-shadow th-carousel" id="blogSlide6" data-slide-show="3" data-lg-slide-show="2" data-md-slide-show="1" data-sm-slide-show="1" data-arrows="true">';
                while( $blogpost->have_posts() ){
                    $blogpost->the_post(); 
                    $categories = get_the_category();
                    echo '<div class="col-md-6 col-xl-4">';
                        echo '<div class="blog-grid style3 wow fadeInUp">';
                            echo '<div class="blog-img global-img">';
                                the_post_thumbnail( 'poolax_387X250' );
                            echo '</div>';
                            echo '<div class="blog-grid_content">';
                                echo '<div class="blog-meta">';
                                    echo '<a href="'.esc_url( get_author_posts_url( get_the_author_meta('ID') ) ).'"><i class="fa-light fa-user"></i>'.esc_html__('By ', 'poolax') . esc_html( ucwords( get_the_author() ) ).'</a>';
                                    echo '<a href="'.esc_url( poolax_blog_date_permalink() ).'"><i class="fa-regular fa-calendar"></i>'.esc_html( get_the_date( ) ).'</a>';
                                echo '</div>';
                                echo '<h3 class="box-title"><a href="'.esc_url( get_permalink() ).'">'.esc_html( wp_trim_words( get_the_title( ), $settings['title_count'], '' ) ).'</a></h3>';
                                if(!empty($settings['read_more'])){
                                    echo '<a href="'.esc_url( get_permalink() ).'" class="th-btn border">'.wp_kses_post($settings['read_more']).'</a>';
                                }
                            echo '</div>';
                        echo '</div>';
                    echo '</div>';
                }
            echo '</div>';

        }elseif( $settings['layout_style'] == '8' ){
            echo '<div class="row slider-shadow th-carousel" id="blogSlide6" data-slide-show="2" data-lg-slide-show="2" data-md-slide-show="1" data-sm-slide-show="1" data-arrows="true">';
                while( $blogpost->have_posts() ){
                    $blogpost->the_post(); 
                    $categories = get_the_category();
                    echo '<div class="col-md-6 col-xl-4">'; 
                        echo '<div class="blog-grid style4 wow fadeInUp">';
                            echo '<div class="blog-img global-img">';
                                the_post_thumbnail( 'poolax_595X350' );
                            echo '</div>';
                            echo '<div class="blog-grid_content">';
                                echo '<div class="blog-meta">';
                                    echo '<a href="'.esc_url( get_author_posts_url( get_the_author_meta('ID') ) ).'"><i class="fa-light fa-user"></i>'.esc_html__('By ', 'poolax') . esc_html( ucwords( get_the_author() ) ).'</a>';
                                    echo '<a href="'.esc_url( poolax_blog_date_permalink() ).'"><i class="fa-regular fa-calendar"></i>'.esc_html( get_the_date( ) ).'</a>';
                                    echo '<a href="'.esc_url( get_permalink() ).'"><i class="fa-regular fa-comments"></i> ';
                                        if(get_comments_number() == 1){
                                            echo esc_html__('Comment (', 'poolax'); 
                                        }else{
                                            echo esc_html__('Comments (', 'poolax'); 
                                        }
                                        echo get_comments_number();
                                    echo ')</a>';
                                echo '</div>';
                                echo '<h3 class="box-title"><a href="'.esc_url( get_permalink() ).'">'.esc_html( wp_trim_words( get_the_title( ), $settings['title_count'], '' ) ).'</a></h3>';
                                if(!empty($settings['read_more'])){
                                    echo '<a href="'.esc_url( get_permalink() ).'" class="th-btn border">'.wp_kses_post($settings['read_more']).'</a>';
                                }
                            echo '</div>';
                        echo '</div>';
                    echo '</div>';
                }
            echo '</div>';

        }else{
			echo '<div class="row slider-shadow th-carousel arrow-wrap" id="blogSlide1" data-slide-show="3" data-lg-slide-show="2" data-md-slide-show="2" data-sm-slide-show="1" data-arrows="true">';
				while( $blogpost->have_posts() ){
					$blogpost->the_post(); 
					$categories = get_the_category();
					echo '<div class="col-md-6 col-xl-4">';
						echo '<div class="blog-card wow fadeInUp">';
							echo '<div class="blog-img global-img">';
								the_post_thumbnail( 'poolax_387X250' );
							echo '</div>';
							echo '<div class="blog-card-content">';
								echo '<div class="blog-meta">';
									echo '<a href="'.esc_url( get_author_posts_url( get_the_author_meta('ID') ) ).'"><i class="fa-light fa-user"></i>'.esc_html__('By ', 'poolax') . esc_html( ucwords( get_the_author() ) ).'</a>';
									echo '<a href="'.esc_url( poolax_blog_date_permalink() ).'"><i class="fa-regular fa-calendar"></i>'.esc_html( get_the_date( ) ).'</a>';
								echo '</div>';
								echo '<h3 class="box-title"><a href="'.esc_url( get_permalink() ).'">'.esc_html( wp_trim_words( get_the_title( ), $settings['title_count'], '' ) ).'</a></h3>';
								if(!empty($settings['read_more'])){
									echo '<a href="'.esc_url( get_permalink() ).'" class="th-btn border">'.wp_kses_post($settings['read_more']).'</a>';
								}
							echo '</div>';
						echo '</div>';
					echo '</div>';
				}
			echo '</div>';
		}

	
      
	}
}