<?php
use \Elementor\Widget_Base;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Typography;
use \Elementor\Utils;
use \Elementor\Group_Control_Image_Size;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Border;
use \Elementor\Repeater;
/**
 *
 * Classes Widget .
 *
 */
class Poolax_Classes extends Widget_Base {

	public function get_name() {
		return 'poolaxclasses';
	}
	public function get_title() {
		return __( 'Classess', 'poolax' );
	}
	public function get_icon() {
		return 'th-icon';
    }
	public function get_categories() {
		return [ 'poolax' ];
	}

	protected function register_controls() {

		 $this->start_controls_section(
			'Classes_section',
			[
				'label'     => __( 'Classess', 'poolax' ),
				'tab'       => Controls_Manager::TAB_CONTENT,
			]
        );

		$this->add_control(
			'layout_style',
			[
				'label' 	=> __( 'Classess Style', 'poolax' ),
				'type' 		=> Controls_Manager::SELECT,
				'default' 	=> '1',
				'options' 	=> [
					'1'  		=> __( 'Style One', 'poolax' ),
					'2'  		=> __( 'Style Two', 'poolax' ),
				],
			]
		);

		$repeater = new Repeater();

		poolax_media_fields($repeater, 'image', 'Image');
		poolax_general_fields($repeater, 'tag', 'Tag / Price', 'TEXT', '$200.99');
		poolax_general_fields($repeater, 'title', 'Title', 'TEXT', 'Pool Cleaning');
		poolax_general_fields($repeater, 'desc', 'Description', 'TEXTAREA', 'Water safety is a top priority in our classes. We teach essential water safety skills.');
		poolax_general_fields($repeater, 'meta', 'Meta Info', 'TEXTAREA', '');
		poolax_url_fields($repeater, 'button_url', 'Button URL');

		$this->add_control(
			'classes_list',
			[
				'label' 		=> __( 'Classes Lists', 'poolax' ),
				'type' 			=> Controls_Manager::REPEATER,
				'fields' 		=> $repeater->get_controls(),
				'default' 		=> [
					[
						'title' 	=> __( 'Pool Cleaning', 'poolax' ),
					],
				],
			]
		);

		poolax_general_fields( $this, 'button__before_text', 'Button Before Text', 'TEXT', 'Offering High Quality Pool Services', ['1'] );
		poolax_general_fields( $this, 'button_text', 'Button Text', 'TEXT', 'Get All Services', ['1'] );
		poolax_url_fields( $this, 'button_url', 'Button URL', '', ['1'] );

        $this->end_controls_section();

        //---------------------------------------
			//Style Section Start
		//---------------------------------------

		//-------Title Style-------
		poolax_common_style_fields($this, 'title', 'Title', '{{WRAPPER}} .title');
		//-------Description Style-------
		poolax_common_style_fields($this, 'desc', 'Description', '{{WRAPPER}} .desc');


	}

	protected function render() {

        $settings = $this->get_settings_for_display();

		if( $settings['layout_style'] == '1' ){
            echo '<div class="row slider-shadow th-carousel" id="serviceSlide4" data-slide-show="3" data-lg-slide-show="2" data-md-slide-show="2" data-sm-slide-show="1" data-arrows="true">';
                foreach( $settings['classes_list'] as $data ){
                    echo '<div class="col-md-6 col-lg-6 col-xl-4">';
                        echo '<div class="service-card-3">';
                            if(!empty($data['image']['url'])){
								echo '<div class="service-card-3_img">';
									echo poolax_img_tag( array(
										'url'   => esc_url( $data['image']['url']  ),
									));
								echo '</div>';
							}
                            echo '<div class="service-card-3_content">';
                                if($data['tag']){
                                    echo '<div class="service-tag">'.wp_kses_post($data['tag']).'</div>';
                                }
                                if($data['title']){
									echo '<h3 class="box-title title"><a href="'.esc_url( $data['button_url']['url'] ).'">'.esc_html($data['title']).'</a></h3>';
								}
								if($data['desc']){
									echo '<p class="service-card-3_text desc">'.esc_html($data['desc']).'</p>';
								}
                                if(!empty($data['meta'])){
                                    echo '<div class="service-meta">'.wp_kses_post($data['meta']).'</div>';
                                }
                            echo '</div>';
                        echo '</div>';
                    echo '</div>';
                }
            echo '</div>';

			if( !empty( $settings['button__before_text'] || $settings['button_text'] ) ){
			echo '<div class="text-center">';
				echo '<div class="service-btn mt-60">';
					if(!empty($settings['button__before_text'])){
						echo '<span>'.wp_kses_post($settings['button__before_text']).'</span>';
					}
					if(!empty($settings['button_text'])){
						echo '<a href="'.esc_url( $settings['button_url']['url'] ).'" class="th-btn th_btn">'.wp_kses_post($settings['button_text']).'</a>';
					}
				echo '</div>';
			echo '</div>';
			}

		}elseif( $settings['layout_style'] == '2' ){
			echo '<div class="row gy-4">';
                foreach( $settings['classes_list'] as $data ){
                    echo '<div class="col-md-6 col-lg-6 col-xl-4">';
                        echo '<div class="service-card-3">';
                            if(!empty($data['image']['url'])){
								echo '<div class="service-card-3_img">';
									echo poolax_img_tag( array(
										'url'   => esc_url( $data['image']['url']  ),
									));
								echo '</div>';
							}
                            echo '<div class="service-card-3_content">';
                                if($data['tag']){
                                    echo '<div class="service-tag">'.wp_kses_post($data['tag']).'</div>';
                                }
                                if($data['title']){
									echo '<h3 class="box-title title"><a href="'.esc_url( $data['button_url']['url'] ).'">'.esc_html($data['title']).'</a></h3>';
								}
								if($data['desc']){
									echo '<p class="service-card-3_text desc">'.esc_html($data['desc']).'</p>';
								}
                                if(!empty($data['meta'])){
                                    echo '<div class="service-meta">'.wp_kses_post($data['meta']).'</div>';
                                }
                            echo '</div>';
                        echo '</div>';
                    echo '</div>';
                }
            echo '</div>';

		}
		

	}

}