
<?php
use \Elementor\Widget_Base;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Typography;
use \Elementor\Utils;
use \Elementor\Group_Control_Image_Size;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Border;
use \Elementor\Repeater;
/**
 *
 * Contact Info Widget .
 *
 */
class Poolax_Contact_Info extends Widget_Base {

	public function get_name() {
		return 'poolaxcontactinfo';
	}
	public function get_title() {
		return __( 'Contact Info', 'poolax' );
	}
	public function get_icon() {
		return 'th-icon';
    }
	public function get_categories() {
		return [ 'poolax' ];
	}

	protected function register_controls() {

		$this->start_controls_section(
			'title_section',
			[
				'label' 	=> __( 'Contact Info', 'poolax' ),
				'tab' 		=> Controls_Manager::TAB_CONTENT,
			]
        );

        $this->add_control(
			'layout_style',
			[
				'label' 	=> __( 'Layout Style', 'poolax' ),
				'type' 		=> Controls_Manager::SELECT,
				'default' 	=> '1',
				'options' 	=> [
					'1'  		=> __( 'Style One', 'poolax' ),
					'2' 		=> __( 'Style Two', 'poolax' ),
					'3' 		=> __( 'Style Three', 'poolax' ),
					'4' 		=> __( 'Style Four', 'poolax' ),
				],
			]
		);

		poolax_media_fields($this, 'logo', 'Logo', ['2']);
		poolax_url_fields($this, 'logo_url', 'Logo URL', '',  ['2']);

		poolax_general_fields( $this, 'address_label', 'Address Label', 'TEXT', 'Address', ['3'] );
		poolax_general_fields( $this, 'address_icon', 'Address Icon', 'TEXT', '<i class="fas fa-map-marker-alt"></i>', ['1', '3', '4'] );
		poolax_general_fields( $this, 'address', 'Address Name', 'TEXTAREA', 'anta Rosa CA 95404, United States', ['1', '3', '4'] );

		poolax_general_fields( $this, 'icon', 'Icon', 'TEXT', '<i class="fa-solid fa-phone"></i>', ['4'] );

		poolax_general_fields( $this, 'phone_icon', 'Phone Icon', 'TEXT', '<i class="fa-solid fa-phone"></i>', ['1', '3'] );
		poolax_media_fields($this, 'phone_icon2', 'Phone Icon', ['2']);
		poolax_general_fields( $this, 'phone_label', 'Phone Label', 'TEXT', 'Phone', ['2', '3', '4'] );
		poolax_general_fields( $this, 'phone', 'Phone Number', 'TEXT', '+(163)-2654-3654' );
		poolax_general_fields( $this, 'phone2', 'Phone Number 2', 'TEXT', '+(163)-2654-3564', ['1', '3'] );

		poolax_general_fields( $this, 'email_icon', 'Email Icon', 'TEXT', '<i class="fas fa-envelope"></i>', ['1', '3'] );
		poolax_media_fields($this, 'email_icon2', 'Email Icon', ['2']);
		poolax_general_fields( $this, 'email_label', 'Email Label', 'TEXT', 'Email', ['2', '3', '4'] );
		poolax_general_fields( $this, 'email', 'Email Address', 'TEXT', 'help24/7@Poolax.com' );
		poolax_general_fields( $this, 'email2', 'Email Address 2', 'TEXT', 'info@Poolax.com', ['3'] );

		poolax_general_fields( $this, 'office_label', 'Office Label', 'TEXT', 'Office', ['3'] );
		poolax_general_fields( $this, 'office_icon', 'Office Icon', 'TEXT', '<i class="fa-light fa-clock"></i>', ['3'] );
		poolax_general_fields( $this, 'office', 'Office Time', 'TEXTAREA', 'Mon-Sat: 9am-8pm Sunday Closed', ['3'] ); 

		poolax_social_fields( $this, 'social_icon_list', 'Social List', ['4'] );

        $this->end_controls_section();

        //---------------------------------------
			//Style Section Start
		//---------------------------------------

		//-------Title Style-------
		poolax_common_style_fields($this, 'title', 'Title', '{{WRAPPER}} .widget_title', ['1']);
		poolax_common_style_fields($this, 'label', 'Label', '{{WRAPPER}} .label', ['2', '3']);
		// poolax_common_style_fields($this, 'label', 'Label', '{{WRAPPER}} .th-info', );

		
	}

	protected function render() {

        $settings = $this->get_settings_for_display();

			
		if( $settings['layout_style'] == '2' ){
			$email = $settings['email'] ? $settings['email'] : '';
			$phone = $settings['phone'] ? $settings['phone'] : '';
             
			$email      = is_email( $email );
	
			$replace        = array(' ','-',' - ');
			$replace_phone        = array(' ','-',' - ', '(', ')');
			$with           = array('','','');
	
			$emailurl       = str_replace( $replace, $with, $email );
			$phoneurl       = str_replace( $replace_phone, $with, $phone );	

			echo '<div class="row gx-0 align-items-center">';
				if(!empty($settings['logo_url']['url'])){
					echo '<div class="col-xl-3">';
						echo '<div class="contact-media style1">';
							echo '<div class="contact-logo">';
								echo '<a href="'.esc_url( $settings['logo_url']['url'] ).'">';
									echo poolax_img_tag( array(
										'url'   => esc_url( $settings['logo']['url'] ),
									));
								echo '</a>';
							echo '</div>';
						echo '</div>';
					echo '</div>';
				}
				echo '<div class="col-xl-9">';
					echo '<div class="contact-media-wrapp">';
						echo '<div class="contact-media bg-theme">';
							if(!empty($settings['phone_icon2']['url'])){
								echo '<div class="contact-media_icon">';
									echo poolax_img_tag( array(
										'url'   => esc_url( $settings['phone_icon2']['url'] ),
									));
								echo '</div>';
							}
							echo '<div class="contact-media_content">';
								if(!empty($settings['phone_label'])){
									echo '<span class="contact-media_subtitle label">'.esc_html($settings['phone_label']).'</span>';
								}
								if(!empty( $phone )){
									echo '<h3 class="contact-media_title"><a href="'.esc_attr('tel:' . $phoneurl).'">'.esc_html($phone).'</a></h3>';
								}
							echo '</div>';
						echo '</div>';
						echo '<div class="contact-media">';
							if(!empty($settings['email_icon2']['url'])){
								echo '<div class="contact-media_icon">';
									echo poolax_img_tag( array(
										'url'   => esc_url( $settings['email_icon2']['url'] ),
									));
								echo '</div>';
							}
							echo '<div class="contact-media_content">';
								if(!empty($settings['email_label'])){
									echo '<p class="contact-media_subtitle label">'.esc_html($settings['email_label']).'</p>';
								}
								if(!empty( $email )){
									echo '<a href="'.esc_attr('mailto:' . $emailurl).'" class="contact-media_title">'.esc_html($email).'</a>';
								}
							echo '</div>';
						echo '</div>';
					echo '</div>';
				echo '</div>';
			echo '</div>';

		}elseif( $settings['layout_style'] == '3' ){
			$email = $settings['email'] ? $settings['email'] : '';
			$email2 = $settings['email2'] ? $settings['email2'] : '';
			$phone = $settings['phone'] ? $settings['phone'] : '';
			$phone2 = $settings['phone2'] ? $settings['phone2'] : '';
             
			$email      = is_email( $email );
	
			$replace        = array(' ','-',' - ');
			$replace_phone        = array(' ','-',' - ', '(', ')');
			$with           = array('','','');
	
			$emailurl       = str_replace( $replace, $with, $email );
			$emailurl2       = str_replace( $replace, $with, $email2 );
			$phoneurl       = str_replace( $replace_phone, $with, $phone );	
			$phoneurl2       = str_replace( $replace_phone, $with, $phone2 );

			echo '<div class="contact-info-wrap">';
				echo '<div class="contact-info">';
					if(!empty($settings['address_icon'])){
						echo '<div class="contact-info_icon">'.wp_kses_post($settings['address_icon']).'</div>';
					}
					echo '<div class="media-body">';
						if(!empty($settings['address_label'])){
							echo '<h3 class="box-title label">'.esc_html($settings['address_label']).'</h3>';
						}
						if(!empty($settings['address'])){
							echo '<span class="contact-info_text th-info">'.wp_kses_post( $settings['address'] ).'</span>';
						}
					echo '</div>';
				echo '</div>';
				echo '<div class="contact-info">';
					if(!empty($settings['phone_icon'])){
						echo '<div class="contact-info_icon">'.wp_kses_post($settings['phone_icon']).'</div>';
					}
					echo '<div class="media-body">';
						if(!empty($settings['phone_label'])){
							echo '<h3 class="box-title label">'.esc_html($settings['phone_label']).'</h3>';
						}
						echo '<span class="contact-info_text">';
							echo '<a href="'.esc_attr('tel:' . $phoneurl).'" class="text-inherit th-info">'.esc_html($phone).'</a>';
							echo '<a href="'.esc_attr('tel:' . $phoneurl2).'" class="text-inherit th-info">'.esc_html($phone2).'</a>';
						echo '</span>';
					echo '</div>';
				echo '</div>';
				echo '<div class="contact-info">';
					if(!empty($settings['email_icon'])){
						echo '<div class="contact-info_icon">'.wp_kses_post($settings['email_icon']).'</div>';
					}
					echo '<div class="media-body">';
						if(!empty($settings['email_label'])){
							echo '<h3 class="box-title label">'.esc_html($settings['email_label']).'</h3>';
						}
						echo '<span class="contact-info_text">';
							echo '<a href="'.esc_attr('mailto:' . $emailurl).'" class="th-info">'.esc_html($email).'</a>';
							echo '<a href="'.esc_attr('mailto:' . $emailurl2).'" class="th-info">'.esc_html($email2).'</a>';
						echo '</span>';
					echo '</div>';
				echo '</div>';
				echo '<div class="contact-info">';
					if(!empty($settings['office_icon'])){
						echo '<div class="contact-info_icon">'.wp_kses_post($settings['office_icon']).'</div>';
					}
					echo '<div class="media-body">';
						if(!empty($settings['office_label'])){
							echo '<h3 class="box-title label">'.esc_html($settings['office_label']).'</h3>';
						}
						if(!empty($settings['office'])){
							echo '<span class="contact-info_text th-info">'.wp_kses_post( $settings['office'] ).'</span>';
						}
					echo '</div>';
				echo '</div>';
			echo '</div>';

		}elseif( $settings['layout_style'] == '4' ){
			$email = $settings['email'] ? $settings['email'] : '';
			$phone = $settings['phone'] ? $settings['phone'] : '';
    
			$email      = is_email( $email );
	
			$replace        = array(' ','-',' - ');
			$replace_phone        = array(' ','-',' - ', '(', ')');
			$with           = array('','','');
	
			$emailurl       = str_replace( $replace, $with, $email );
			$phoneurl       = str_replace( $replace_phone, $with, $phone );	

			echo '<div class="widget footer-widget style2">';
				echo '<div class="info-box_wrapper">';
					if(!empty( $phone || $email )){
						echo '<div class="info-box">';
							if(!empty($settings['icon'])){
								echo '<div class="info-box_icon">'.wp_kses_post($settings['icon']).'</div>';
							}
							echo '<p class="info-box_text">';
									echo '<a href="'.esc_attr('tel:' . $phoneurl).'" class="info-box_link">'.esc_html($settings['phone_label'] . $phone).'</a>';
									echo '<a class="info-box_link" href="'.esc_attr('mailto:' . $emailurl).'">'.esc_html($settings['email_label'] . $email).'</a>';
							echo '</p>';
						echo '</div>';
					}
					echo '<div class="info-box">';
						echo '<div class="th-social">';
							foreach( $settings['social_icon_list'] as $social_icon ){
								$social_target    = $social_icon['icon_link']['is_external'] ? ' target="_blank"' : '';
								$social_nofollow  = $social_icon['icon_link']['nofollow'] ? ' rel="nofollow"' : '';
			
								echo '<a '.wp_kses_post( $social_target.$social_nofollow ).' href="'.esc_url( $social_icon['icon_link']['url'] ).'">';
			
								\Elementor\Icons_Manager::render_icon( $social_icon['social_icon'], [ 'aria-hidden' => 'true' ] );
			
								echo '</a> ';
							}
						echo '</div>';
					echo '</div>';
					echo '<div class="info-box">';
						if(!empty($settings['address_icon'])){
							echo '<div class="info-box_icon">'.wp_kses_post($settings['address_icon']).'</div>';
						}
						if(!empty($settings['address'])){
							echo '<p class="info-box_text th-info">'.wp_kses_post( $settings['address'] ).'</p>';
						}
					echo '</div>';
				echo '</div>';
			echo '</div>';

		}else{
			$email = $settings['email'] ? $settings['email'] : '';
			$phone = $settings['phone'] ? $settings['phone'] : '';
			$phone2 = $settings['phone2'] ? $settings['phone2'] : '';
             
			$email      = is_email( $email );
	
			$replace        = array(' ','-',' - ');
			$replace_phone        = array(' ','-',' - ', '(', ')');
			$with           = array('','','');
	
			$emailurl       = str_replace( $replace, $with, $email );
			$phoneurl       = str_replace( $replace_phone, $with, $phone );	
			$phoneurl2       = str_replace( $replace_phone, $with, $phone2 );	

			echo '<div class="widget footer-widget">';
				echo '<h3 class="widget_title">Contact Us</h3>';
				echo '<div class="th-widget-about">';
					if(!empty( $settings['address'] )){
						echo '<p class="footer-info">
							'.wp_kses_post( $settings['address_icon'] . $settings['address'] ).'
							</p>';
					}
					if(!empty( $phone || $phone2 )){
						echo '<div class="footer-info"> 
								'.wp_kses_post($settings['phone_icon']).'
								<p class="footer-info_text">
									<a href="'.esc_attr('tel:' . $phoneurl).'" class="text-inherit">'.esc_html($phone).'</a>
									<a href="'.esc_attr('tel:' . $phoneurl2).'" class="text-inherit">'.esc_html($phone2).'</a>
								</p>
							</div>';
					}
					if(!empty( $email )){
						echo '<p class="footer-info">
								'.wp_kses_post($settings['email_icon']).'
								<a class="text-inherit" href="'.esc_attr('mailto:' . $emailurl).'">'.esc_html($email).'</a>
							</p>';
					}
				echo '</div>';
			echo '</div>';
		}
       

	}

}
