<?php
use \Elementor\Widget_Base;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Typography;
use \Elementor\Utils;
use \Elementor\Group_Control_Image_Size;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Border;
use \Elementor\Repeater;
/**
 *
 * CTA Widget .
 *
 */
class poolax_Cta extends Widget_Base {

	public function get_name() {
		return 'poolaxcta';
	}
	public function get_title() {
		return __( 'CTA', 'poolax' );
	}
	public function get_icon() {
		return 'th-icon';
    }
	public function get_categories() {
		return [ 'poolax' ];
	}

	protected function register_controls() {


		 $this->start_controls_section(
			'section_title_section',
			[
				'label'		 	=> __( 'CTA', 'poolax' ),
				'tab' 			=> Controls_Manager::TAB_CONTENT,
				
			]
        );

		$this->add_control(
			'layout_style',
			[
				'label' 		=> __( 'Layout Style', 'poolax' ),
				'type' 			=> Controls_Manager::SELECT,
				'default' 		=> '1',
				'options' 		=> [
					'1'  		=> __( 'Style One', 'poolax' ),					
					'2'  		=> __( 'Style Two', 'poolax' ),					
				],
			]
		);

		$this->add_control(
			'image',
			[
				'label'     => __( 'Image', 'poolax' ),
				'type'      => Controls_Manager::MEDIA,
				'dynamic'   => [
					'active' => true,
				],
			]
		);

        $this->add_control(
			'image2',
			[
				'label'     => __( 'Image 2', 'poolax' ),
				'type'      => Controls_Manager::MEDIA,
				'dynamic'   => [
					'active' => true,
				],
			]
		);

        $this->add_control(
			'icon',
			[
				'label'     => __( 'Icon', 'poolax' ),
				'type'      => Controls_Manager::MEDIA,
				'dynamic'   => [
					'active' => true,
				],
				'condition' => [
					'layout_style' => ['2']
				]
			]
		);

		$this->add_control(
			'title',
            [
				'label'         => __( 'Title', 'poolax' ),
				'type'          => Controls_Manager::TEXTAREA,
				'default'       => __( 'title here' , 'poolax' ),
				'label_block'   => true,
				'rows' => '2',
			]
		);
		$this->add_control(
			'desc',
            [
				'label'         => __( 'Description', 'poolax' ),
				'type'          => Controls_Manager::TEXTAREA,
				'default'       => __( 'Description here' , 'poolax' ),
				'label_block'   => true,
				'rows' => '2',
				'condition' => [
					'layout_style' => ['2']
				]
			]
		);

		$this->add_control(
			'button_text',
			[
				'label' 	=> __( 'Button Text', 'poolax' ),
                'type' 		=> Controls_Manager::TEXT,
                'label_block' => true,
                'default'  	=> __( 'Button Text', 'poolax' ),
			]
        );

        $this->add_control(
			'button_link',
			[
				'label' 		=> __( 'Link', 'poolax' ),
				'type' 			=> Controls_Manager::URL,
				'placeholder' 	=> __( 'https://your-link.com', 'poolax' ),
				'show_external' => true,
				'default' 		=> [
					'url' 			=> '#',
					'is_external' 	=> false,
					'nofollow' 		=> false,
				],
			]
		); 
        $this->add_control(
			'video_link',
			[
				'label' 		=> __( 'Video Link', 'poolax' ),
				'type' 			=> Controls_Manager::URL,
				'placeholder' 	=> __( 'https://your-link.com', 'poolax' ),
				'show_external' => true,
				'default' 		=> [
					'url' 			=> '#',
					'is_external' 	=> false,
					'nofollow' 		=> false,
				],
				'condition' => [
					'layout_style' => ['2']
				]
			]
		); 

        $this->end_controls_section();

        //---------------------------------------
			//Style Section Start
		//---------------------------------------
		poolax_common_style_fields($this, 'title', 'Title', '{{WRAPPER}} .title');
		poolax_common_style_fields($this, 'desc', 'Description', '{{WRAPPER}} .desc', ['2']);

		poolax_button_style_fields($this, '11', 'Button Styling', '{{WRAPPER}} .th_btn', ['1', '2']);
	

	}

	protected function render() {

	$settings = $this->get_settings_for_display();
	?>

        <?php if( $settings['layout_style'] == '2' ): 
			
			echo '<div class="cta-sec5 bg-theme overflow-hidden" data-bg-src="'.esc_url( $settings['image']['url']).'">';
				echo '<div class="cta-thumb shape-mockup" data-top="0" data-right="0">';
					echo poolax_img_tag( array(
						'url'   => esc_url( $settings['image2']['url'] ),
					));
					if(!empty($settings['video_link']['url'])){
						echo '<a href="'.esc_url( $settings['video_link']['url'] ).'" class="play-btn popup-video"><i class="fa-sharp fa-solid fa-play"></i></a>';
					}
				echo '</div>';
				echo '<div class="container">';
					echo '<div class="row align-items-center">';
						echo '<div class=" col-lg-9 col-xl-6">';
							echo '<div class="cta-title-area">';
								if(!empty($settings['icon']['url'])){
									echo '<div class="cta-shape">';
										echo poolax_img_tag( array(
											'url'   => esc_url( $settings['icon']['url'] ),
										));
									echo '</div>';
								}
								echo '<div class="title-area mb-0">';
									if($settings['title']){
										echo '<h2 class="cta-text mb-lg-0 title">'.esc_html($settings['title']).'</h2>';
									}
									if($settings['desc']){
										echo '<p class="mb-0 desc">'.esc_html($settings['desc']).'</p>';
									}
								echo '</div>';
							echo '</div>';
						echo '</div>';
						if(!empty($settings['button_text'])){
							echo '<div class="col-lg-3 col-xl-3 text-md-end">';
								echo '<div class="btn-group justify-content-center justify-content-lg-start">';
									echo '<a href="'.esc_url( $settings['button_link']['url'] ).'" class="th-btn style9 th_btn">'.wp_kses_post($settings['button_text']).'</a>';
								echo '</div>';
							echo '</div>';
						}
					echo '</div>';
				echo '</div>';
			echo '</div>';

		?>

    	<?php else: ?>
			<div class="cta-area-2 text-center text-lg-start">
				<div class="cta-bg-thumb">
					<?php echo poolax_img_tag( array(
							'url'   => esc_url( $settings['image']['url'] ),
						)); ?>
				</div>
				<div class="container">
					<div class="row justify-content-between align-items-center">
						<div class="col-xl-6 col-lg-6">
							<div class="title-area mb-lg-0">
								<h2 class="sec-title text-white th-title"><?php echo esc_html($settings['title']); ?></h2>
							</div>
						</div>
						<div class="col-lg-auto">
							<a href="<?php echo esc_url( $settings['button_link']['url'] ); ?>" class="th-btn cta-btn th_btn" data-bg-src="<?php echo esc_url( $settings['image2']['url']); ?>"><?php echo wp_kses_post($settings['button_text']); ?></a>
						</div>
					</div>
				</div>
			</div>

		<?php endif;

	}

}