<?php
use \Elementor\Widget_Base;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Typography;
use \Elementor\Utils;
use \Elementor\Group_Control_Image_Size;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Border;
use \Elementor\Repeater;
/**
 *
 * Gallery Filter Widget .
 *
 */
class Poolax_Gallery_Filter extends Widget_Base {

	public function get_name() {
		return 'poolaxgalleryfilter';
	}
	public function get_title() {
		return __( 'Gallery Filter', 'poolax' );
	}
	public function get_icon() {
		return 'th-icon';
    }
	public function get_categories() {
		return [ 'poolax' ];
	}

	protected function register_controls() {

		 $this->start_controls_section(
			'service_section',
			[
				'label'     => __( 'Gallery Filter', 'poolax' ),
				'tab'       => Controls_Manager::TAB_CONTENT,
			]
        );

		$this->add_control(
			'layout_style',
			[
				'label' 	=> __( 'Layout Style', 'poolax' ),
				'type' 		=> Controls_Manager::SELECT,
				'default' 	=> '1',
				'options' 	=> [
					'1'  		=> __( 'Style One', 'poolax' ),
				],
			]
		);

		poolax_switcher_fields($this, 'show_all', 'Show All Tab?');
		poolax_general_fields($this, 'all_title', 'All Tab Text', 'TEXT', 'All Photos');

		$repeater = new Repeater();

		poolax_general_fields($repeater, 'tab_title', 'Tab Title', 'TEXT', 'Residential');
		poolax_general_fields($repeater, 'tab_id', 'Filter Tab ID', 'TEXT', 'cat1');

		$this->add_control(
			'gallery_tab',
			[
				'label' 		=> __( 'Gallery Tab', 'poolax' ),
				'type' 			=> Controls_Manager::REPEATER,
				'fields' 		=> $repeater->get_controls(),
				'default' 		=> [
					[
						'tab_title' 		=> __( 'Residential', 'poolax' ),
					],
				],
			]
		);

		$repeater = new Repeater();

		poolax_general_fields($repeater, 'tab_id2', 'Filter Content ID', 'TEXT', 'cat1');
		poolax_media_fields($repeater, 'image', 'Choose Image');
		poolax_general_fields($repeater, 'subtitle', 'Subtitle', 'TEXT', 'Residential');
		poolax_general_fields($repeater, 'title', 'Title', 'TEXTAREA', 'Pool Water Cleaning');
		poolax_url_fields($repeater, 'button_url', 'Button URL');

		$this->add_control(
			'gallery_list',
			[
				'label' 		=> __( 'Gallery Lists', 'poolax' ),
				'type' 			=> Controls_Manager::REPEATER,
				'fields' 		=> $repeater->get_controls(),
				'default' 		=> [
					[
						'title' 		=> __( 'Pool Water Cleaning', 'poolax' ),
					],
				],
			]
		);

        $this->end_controls_section();

        //---------------------------------------
			//Style Section Start
		//---------------------------------------

		//-------Subtitle Style-------
		poolax_common_style_fields($this, 'subtitle', 'Subtitle', '{{WRAPPER}} .project-subtitle' );
		//-------Title Style-------
		poolax_common_style_fields($this, 'title', 'Title', '{{WRAPPER}} .box-title a');

	}

	protected function render() {

        $settings = $this->get_settings_for_display();

		if( $settings['layout_style'] == '2' ){

		}else{
			echo '<div class="gallery-tabs indicator-active filter-menu-active">';
				if(!empty($settings['show_all'])){
					$active = '';
					if(!empty($settings['all_title'])){
						$title = $settings['all_title'];
					}else{
						$title = 'All Photos';
					}
					echo '<button data-filter="*" class="th-btn tab-btn active" type="button">'.esc_html($title).'</button>';
				}else{
					$active = 'active';
				}
				foreach( $settings['gallery_tab'] as $key => $data ){
					$id = strtolower($data['tab_id']);
					$active_class = ($key == 0) ? $active : '';
				echo '<button data-filter=".'.esc_attr($id).'" class="th-btn tab-btn '.esc_attr($active_class).'" type="button">'.esc_html($data['tab_title']).'</button>';
				}
			echo '</div>';

			echo '<div class="row gallery-row filter-active">';
				foreach( $settings['gallery_list'] as $data ){
					$id = strtolower($data['tab_id2']);
					echo '<div class="col-md-6 col-lg-auto filter-item '.esc_attr($id).'">';
						echo '<div class="project-item style2">';
							echo '<div class="project-img">';
								echo poolax_img_tag( array(
									'url'   => esc_url( $data['image']['url'] ),
								));
							echo '</div>';
							echo '<div class="project-content">';
								echo '<div class="media-left">';
									if(!empty($data['subtitle'])){
										echo '<p class="project-subtitle">'.wp_kses_post($data['subtitle']).'</p>';
									}
									if(!empty($data['title'])){
										echo '<h4 class="box-title"><a href="'.esc_url( $data['button_url']['url'] ).'">'.wp_kses_post($data['title']).'</a></h4>';
									}
									echo '<a href="'.esc_url( $data['image']['url'] ).'" class="icon-btn popup-image"><i class="far fa-plus"></i></a>';
								echo '</div>';
							echo '</div>';
						echo '</div>';
					echo '</div>';
				}
			echo '</div>';
		}


	}

}