<?php
use \Elementor\Widget_Base;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Typography;
use \Elementor\Utils;
use \Elementor\Group_Control_Image_Size;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Border;
/**
 *
 * Image Widget .
 *
 */
class Poolax_Image extends Widget_Base {

	public function get_name() {
		return 'poolaximage';
	}
	public function get_title() {
		return __( 'Image', 'poolax' );
	}
	public function get_icon() {
		return 'th-icon';
    }
	public function get_categories() {
		return [ 'poolax' ];
	}

	protected function register_controls() {

		$this->start_controls_section(
			'image_section',
			[
				'label' 	=> __( 'Image', 'poolax' ),
				'tab' 		=> Controls_Manager::TAB_CONTENT,
			]
        );

		$this->add_control(
			'layout_style',
			[
				'label' 	=> __( 'Layout Style', 'poolax' ),
				'type' 		=> Controls_Manager::SELECT,
				'default' 	=> '1',
				'options' 	=> [
					'1'  		=> __( 'Style One', 'poolax' ),
					'2' 		=> __( 'Style Two', 'poolax' ),
					'3' 		=> __( 'Style Three', 'poolax' ),
					'4' 		=> __( 'Style Four', 'poolax' ),
					'5' 		=> __( 'Style Five', 'poolax' ),
					'6' 		=> __( 'Style Six', 'poolax' ),
					'7' 		=> __( 'Style Seven', 'poolax' ),
					'8' 		=> __( 'Style Eight', 'poolax' ),
					'9' 		=> __( 'Style Nine', 'poolax' ),
					'10' 		=> __( 'Style Ten', 'poolax' ),
					'11' 		=> __( 'Style Eleven', 'poolax' ),
					'12' 		=> __( 'Style Twelve', 'poolax' ),
					'13' 		=> __( 'Style Thirteen', 'poolax' ),
				],
			]
		);

		poolax_media_fields($this, 'image1', 'Choose Image');
		poolax_media_fields($this, 'image2', 'Choose Image', ['1', '2', '3', '4', '7', '10', '11', '13']);
		poolax_media_fields($this, 'image3', 'Choose Image', ['1', '10', '11', '13']);
		poolax_media_fields($this, 'image4', 'Choose Image', ['11', '12']);
		poolax_general_fields($this, 'exp_year', 'Experience Year', 'TEXT', '25', ['2', '3', '5', '7', '10']);
		poolax_general_fields($this, 'exp_info', 'Experience Info', 'TEXTAREA', 'Experience', ['2', '3', '5', '7', '10']);
		poolax_url_fields($this, 'video_url', 'Button URL','', ['4']);
 

       $this->end_controls_section();

      	//---------------------------------------
			//Style Section Start
		//---------------------------------------


	}

	protected function render() {

        $settings = $this->get_settings_for_display();
       
		if( $settings['layout_style'] == '2' ){
			echo '<div class="img-box1">';
				if(!empty($settings['image1']['url'])){
					echo '<div class="img1">';
						echo poolax_img_tag( array(
							'url'   => esc_url( $settings['image1']['url'] ),
						));
					echo '</div>';
				}
				if(!empty($settings['image2']['url'])){
					echo '<div class="img2 global-img movingX">';
						echo poolax_img_tag( array(
							'url'   => esc_url( $settings['image2']['url'] ),
						));
					echo '</div>';
				}
				echo '<div class="th-experience jump">';
					if(!empty($settings['exp_year'])){
						echo '<h3 class="experience-year">'.wp_kses_post($settings['exp_year']).'</h3>';
					}
					if(!empty($settings['exp_info'])){
						echo '<p class="experience-text">'.wp_kses_post($settings['exp_info']).'</p>';
					}
				echo '</div>';
			echo '</div>';

		}elseif( $settings['layout_style'] == '3' ){
			echo '<div class="img-box3">';
				if(!empty($settings['image1']['url'])){
					echo '<div class="img3 wow fadeInUp">';
						echo poolax_img_tag( array(
							'url'   => esc_url( $settings['image1']['url'] ),
						));
					echo '</div>';
				}
				if(!empty($settings['image2']['url'])){
					echo '<div class="img4 wow fadeInRight">';
						echo poolax_img_tag( array(
							'url'   => esc_url( $settings['image2']['url'] ),
						));
					echo '</div>';
				}
				echo '<div class="th-experience style2">';
					if(!empty($settings['exp_year'])){
						echo '<h3 class="experience-year">'.wp_kses_post($settings['exp_year']).'</h3>';
					}
					if(!empty($settings['exp_info'])){
						echo '<p class="experience-text">'.wp_kses_post($settings['exp_info']).'</p>';
					}
				echo '</div>';
			echo '</div>';

		}elseif( $settings['layout_style'] == '4' ){
			echo '<div class="img-box4">';
				if(!empty($settings['image1']['url'])){
					echo '<div class="img1">';
						echo poolax_img_tag( array(
							'url'   => esc_url( $settings['image1']['url'] ),
						));
					echo '</div>';
				}
				if(!empty($settings['image2']['url'])){
					echo '<div class="img2">';
						echo poolax_img_tag( array(
							'url'   => esc_url( $settings['image2']['url'] ),
						));
					echo '</div>';
				}
				if(!empty($settings['video_url']['url'])){
					echo '<div class="why-video">';
						echo '<a href="'.esc_url( $settings['video_url']['url'] ).'" class="play-btn popup-video"><i class="fa-light fa-play"></i></a>';
					echo '</div>';
				}
			echo '</div>';

		}elseif( $settings['layout_style'] == '5' ){
			echo '<div class="img-box5 pe-xl-5">';
				if(!empty($settings['image1']['url'])){
					echo '<div class="img1">';
						echo poolax_img_tag( array(
							'url'   => esc_url( $settings['image1']['url'] ),
						));
					echo '</div>';
				}
				echo '<div class="th-experience jump">';
					if(!empty($settings['exp_year'])){
						echo '<h3 class="experience-year">'.wp_kses_post($settings['exp_year']).'</h3>';
					}
					if(!empty($settings['exp_info'])){
						echo '<p class="experience-text">'.wp_kses_post($settings['exp_info']).'</p>';
					}
				echo '</div>';
			echo '</div>';

		}elseif( $settings['layout_style'] == '6' ){
			if(!empty($settings['image1']['url'])){
				echo '<div class="img-box6">';
					echo '<div class="img1 global-img">';
						echo poolax_img_tag( array(
							'url'   => esc_url( $settings['image1']['url'] ),
						));
					echo '</div>';
					echo '<div class="about-shape6-1"></div>';
					echo '<div class="about-shape6-2"></div>';
					echo '<div class="about-shape6-3"></div>';
				echo '</div>';
			}

		}elseif( $settings['layout_style'] == '7' ){
			echo '<div class="faq-image2 style2">';
				if(!empty($settings['image1']['url'])){
					echo '<div class="img1">';
						echo poolax_img_tag( array(
							'url'   => esc_url( $settings['image1']['url'] ),
						));
					echo '</div>';
				}
				echo '<div class="th-experience">';
					if(!empty($settings['exp_year'])){
						echo '<h3 class="experience-year">'.wp_kses_post($settings['exp_year']).'</h3>';
					}
					if(!empty($settings['exp_info'])){
						echo '<p class="experience-text">'.wp_kses_post($settings['exp_info']).'</p>';
					}
				echo '</div>';
				if(!empty($settings['image2']['url'])){
					echo '<div class="faq-shape">';
						echo poolax_img_tag( array(
							'url'   => esc_url( $settings['image2']['url'] ),
						));
					echo '</div>';
				}
			echo '</div>';

		}elseif( $settings['layout_style'] == '8' ){
			if(!empty($settings['image1']['url'])){
				echo '<div class="img-box8 mb-40 mb-xl-0 me-xl-5">';
					echo '<div class="img1">';
						echo poolax_img_tag( array(
							'url'   => esc_url( $settings['image1']['url'] ),
						));
					echo '</div>';
				echo '</div>';
			}

		}elseif( $settings['layout_style'] == '9' ){
			if(!empty($settings['image1']['url'])){
				echo '<div class="why-choose-image mb-40 mb-xl-0 me-xl-5">';
					echo '<div class="img1">';
						echo poolax_img_tag( array(
							'url'   => esc_url( $settings['image1']['url'] ),
						));
					echo '</div>';
				echo '</div>';
			}

		}elseif( $settings['layout_style'] == '10' ){
			echo '<div class="img-box10">';
				if(!empty($settings['image1']['url'])){
					echo '<div class="img1">';
						echo poolax_img_tag( array(
							'url'   => esc_url( $settings['image1']['url'] ),
						));
					echo '</div>';
				}
				if(!empty($settings['image2']['url'])){
					echo '<div class="img2">';
						echo poolax_img_tag( array(
							'url'   => esc_url( $settings['image2']['url'] ),
						));
					echo '</div>';
				}
				if(!empty($settings['image3']['url'])){
					echo '<div class="img3">';
						echo poolax_img_tag( array(
							'url'   => esc_url( $settings['image3']['url'] ),
						));
					echo '</div>';
				}
				echo '<div class="th-experience style3">';
					if(!empty($settings['exp_year'])){
						echo '<h2 class="experience-year">'.wp_kses_post($settings['exp_year']).'</h2>';
					}
					if(!empty($settings['exp_info'])){
						echo '<p class="experience-text">'.wp_kses_post($settings['exp_info']).'</p>';
					}
				echo '</div>';
			echo '</div>';

		}elseif( $settings['layout_style'] == '11' ){
			echo '<div class="img-box11">';
				if(!empty($settings['image1']['url'])){
					echo '<div class="img1">';
						echo poolax_img_tag( array(
							'url'   => esc_url( $settings['image1']['url'] ),
						));
					echo '</div>';
				}
				if(!empty($settings['image2']['url'])){
					echo '<div class="choose-shape">';
						echo poolax_img_tag( array(
							'url'   => esc_url( $settings['image2']['url'] ),
						));
					echo '</div>';
				}
				if(!empty($settings['image3']['url'])){
					echo '<div class="img1">';
						echo poolax_img_tag( array(
							'url'   => esc_url( $settings['image3']['url'] ),
						));
					echo '</div>';
				}
				if(!empty($settings['image4']['url'])){
					echo '<div class="img2">';
						echo poolax_img_tag( array(
							'url'   => esc_url( $settings['image4']['url'] ),
						));
					echo '</div>';
				}
			echo '</div>';

		}elseif( $settings['layout_style'] == '12' ){
			echo '<div class="choose-image">';
				if(!empty($settings['image1']['url'])){
					echo '<div class="img1">';
						echo poolax_img_tag( array(
							'url'   => esc_url( $settings['image1']['url'] ),
						));
					echo '</div>';
				}
				if(!empty($settings['image4']['url'])){
					echo '<div class="img1">';
						echo poolax_img_tag( array(
							'url'   => esc_url( $settings['image4']['url'] ),
						));
					echo '</div>';
				}
			echo '</div>';

		}elseif( $settings['layout_style'] == '13' ){
			echo '<div class="faq-img6">';
				if(!empty($settings['image1']['url'])){
					echo '<div class="img1">';
						echo poolax_img_tag( array(
							'url'   => esc_url( $settings['image1']['url'] ),
						));
					echo '</div>';
				}
				if(!empty($settings['image2']['url'])){
					echo '<div class="img2">';
						echo poolax_img_tag( array(
							'url'   => esc_url( $settings['image2']['url'] ),
						));
					echo '</div>';
				}
				if(!empty($settings['image3']['url'])){
					echo '<div class="faq-shape">';
						echo poolax_img_tag( array(
							'url'   => esc_url( $settings['image3']['url'] ),
						));
					echo '</div>';
				}
			echo '</div>';

		}else{
			echo '<div class="img-box2">';
				echo '<div class="img1 global-img">';
					echo poolax_img_tag( array(
						'url'   => esc_url( $settings['image1']['url'] ),
					));
				echo '</div>';
				echo '<div class="img2 global-img movingX">';
					echo poolax_img_tag( array(
						'url'   => esc_url( $settings['image2']['url'] ),
					));
				echo '</div>';
				echo '<div class="img3 global-img jump">';
					echo poolax_img_tag( array(
						'url'   => esc_url( $settings['image3']['url'] ),
					));
				echo '</div>';
			echo '</div>';
		}



	}

}