<?php
use \Elementor\Widget_Base;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Typography;
use \Elementor\Utils;
use \Elementor\Repeater;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Background;
/**
 * 
 * Newsletter Widget .
 *
 */
class Poolax_Newsletter extends Widget_Base {

	public function get_name() {
		return 'poolaxnewsletter';
	}
	public function get_title() {
		return __( 'Newsletter', 'poolax' );
	}
	public function get_icon() {
		return 'th-icon';
    }
	public function get_categories() {
		return [ 'poolax' ];
	}
	
	protected function register_controls() {

		$this->start_controls_section(
			'layout_section',
			[
				'label'     => __( 'Newsletter Style', 'poolax' ),
				'tab'       => Controls_Manager::TAB_CONTENT,
			]
        );

		$this->add_control(
			'layout_style',
			[
				'label' 	=> __( 'Layout Style', 'poolax' ),
				'type' 		=> Controls_Manager::SELECT,
				'default' 	=> '1',
				'options' 	=> [
					'1'  		=> __( 'Style One', 'poolax' ),
					'2' 		=> __( 'Style Two', 'poolax' ),
					'3' 		=> __( 'Style Three', 'poolax' ),
					'4' 		=> __( 'Style Four', 'poolax' ),
					'5' 		=> __( 'Style Five', 'poolax' ),
					'6' 		=> __( 'Style Six', 'poolax' ),
					'7' 		=> __( 'Style Seven', 'poolax' ),
					'8' 		=> __( 'Style Eight', 'poolax' ),
				],
			]
		);

		poolax_general_fields($this, 'title', 'Title', 'TEXTAREA', 'Sign Up to get updates & news about us.', ['1', '3', '5', '6', '8']);
		poolax_media_fields($this, 'logo', 'Logo', ['2']);
		poolax_url_fields($this, 'logo_url', 'Logo URL', '',  ['2']);
		poolax_general_fields($this, 'desc', 'Info', 'TEXTAREA', 'Provide specialized winterization services Sign Up to get updates & news about us.', '2');

		poolax_media_fields($this, 'bg', 'Background Image', ['8']);
		poolax_media_fields($this, 'image', 'Phone Icon', ['4']);
		poolax_general_fields($this, 'label', 'Label', 'TEXTAREA2', 'Call us 24/7', ['4']);
		poolax_general_fields($this, 'content', 'Content', 'TEXTAREA', '', ['4']);
		poolax_general_fields($this, 'phone', 'Phone url', 'TEXTAREA2', 'tel:+46825476243', ['4']);
		poolax_media_fields($this, 'image2', 'Subscribe Icon', ['4']);
		poolax_general_fields($this, 'label2', 'Label', 'TEXTAREA2', 'Subscribe', ['4']);
		poolax_general_fields($this, 'content2', 'Content', 'TEXTAREA', '', ['4']);

		poolax_general_fields($this, 'newsletter_placeholder', 'Placeholder', 'TEXT', 'Enter your Email');
		poolax_general_fields($this, 'newsletter_button', 'Subscribe Button', 'TEXT', 'Subscribe');
		poolax_social_fields($this, 'social_icon_list', 'Social Media', ['2']);
		poolax_media_fields($this, 'shape', 'Choose Shape', ['5']);
		poolax_media_fields($this, 'shape2', 'Choose Shape', ['5']);

        $this->end_controls_section();

        //---------------------------------------
			//Style Section Start
		//---------------------------------------

		//-------General Style-------
		$this->start_controls_section(
			'general_styling',
			[
				'label'     => __( 'General Styling', 'poolax' ),
				'tab'       => Controls_Manager::TAB_STYLE,
				'condition'	=> [
					'layout_style' => ['1', '3', '5', '6'],
				]
			]
        );

		poolax_color_fields($this, 'bg_color', 'Backgorund Color', '--theme-color', '{{WRAPPER}} .bg');

		$this->end_controls_section();

		$this->start_controls_section(
			'general_styling2',
			[
				'label'     => __( 'General Styling', 'poolax' ),
				'tab'       => Controls_Manager::TAB_STYLE,
				'condition'	=> [
					'layout_style' => ['8'],
				]
			]
        );

		poolax_color_fields($this, 'bg_color2', 'Backgorund Color', 'background-color', '{{WRAPPER}} .bg');

		$this->end_controls_section();

		//-------Title Style-------
		poolax_common_style_fields($this, 'title', 'Title', '{{WRAPPER}} .title', ['1', '3', '5', '6', '8']);
		//-------Description Style-------
		poolax_common_style_fields($this, 'desc', 'Info', '{{WRAPPER}} .th-info', ['2']);

		poolax_common_style_fields($this, 'label2', 'Label', '{{WRAPPER}} .footer-info_label', ['4']);
		poolax_common_style_fields($this, 'label3', 'Content', '{{WRAPPER}} .content', ['4']);

		//------Button Style-------
		poolax_button_style_fields($this, '12', 'Button Styling', '{{WRAPPER}} .th-btn', ['1', '2', '3', '4', '5', '6']);


	}

	protected function render() {

        $settings = $this->get_settings_for_display();

		if( $settings['layout_style'] == '2' ){
			echo '<div class="widget footer-widget">
					<div class="th-widget-about">
						<div class="about-logo text-center">';
							echo '<a href="'.esc_url( $settings['logo_url']['url'] ).'">';
								echo poolax_img_tag( array(
									'url'   => esc_url( $settings['logo']['url'] ),
								));
							echo '</a>
						</div>';
						if($settings['desc']){
							echo '<p class="text-center th-info">'.wp_kses_post($settings['desc']).'</p>';
						}
						echo '<div class="footer-search-contact mt-25">
							<form>
								<input class="form-control" type="email" placeholder="'.esc_attr( $settings['newsletter_placeholder'] ).'l">
							</form>
							<div class="">
								<button type="submit" class="th-btn">'.wp_kses_post( $settings['newsletter_button'] ).'</button>
							</div>
						</div>
						<div class="th-social footer-social mt-30 text-center">';
							foreach( $settings['social_icon_list'] as $social_icon ){
								$social_target    = $social_icon['icon_link']['is_external'] ? ' target="_blank"' : '';
								$social_nofollow  = $social_icon['icon_link']['nofollow'] ? ' rel="nofollow"' : '';

								echo '<a '.wp_kses_post( $social_target.$social_nofollow ).' href="'.esc_url( $social_icon['icon_link']['url'] ).'">';

								\Elementor\Icons_Manager::render_icon( $social_icon['social_icon'], [ 'aria-hidden' => 'true' ] );

								echo '</a> ';
							}
						echo '</div>
					</div>
				</div>';

		}elseif( $settings['layout_style'] == '3' ){
			echo '<div class="newsletter-sec bg-theme bg"> ';  
				echo '<div class="row gx-0 align-items-center">';                            
					if($settings['title']){
						echo '<div class="col-lg-6 col-xl-5">';
							echo '<div class="newsletter-wrapper">';
								echo '<h4 class="h4 newsletter-title title mb-0">'.wp_kses_post($settings['title']).'</h4>';
							echo '</div>';
						echo '</div>';
					}
					echo '<div class="col-lg-6 col-xl-7">';
						echo '<div class="newsletter-form-wrapper">';
							echo '<form class="newsletter-form">';
								echo '<input class="form-control " type="email" placeholder="'.esc_attr( $settings['newsletter_placeholder'] ).'" required="">';
								echo '<button type="submit" class="th-btn style3">'.wp_kses_post( $settings['newsletter_button'] ).'</button>';
							echo '</form>';
						echo '</div>';
					echo '</div>';
				echo '</div>';
			echo '</div>';

		}elseif( $settings['layout_style'] == '4' ){
			echo '<div class="footer-icon-wrapper">';
				echo '<div class="footer-wrapp">';
					echo '<div class="footer-info">';
						echo '<div class="footer-icon">';
							echo '<a href="'.esc_attr($settings['phone']).'">';
								echo poolax_img_tag( array(
									'url'   => esc_url( $settings['image']['url'] ),
								));
							echo '</a>';
						echo '</div>';
						echo '<div class="media-body">';
							if($settings['label']){
								echo '<span class="footer-info_label">'.wp_kses_post($settings['label']).'</span>';
							}
							if($settings['content']){
								echo '<p class="footer-info_link"><a class="content" href="'.esc_attr($settings['phone']).'">'.wp_kses_post($settings['content']).'</a></p>';
							}
						echo '</div>';
					echo '</div>';
					echo '<div class="footer-info">';
						echo '<div class="footer-icon">';
							echo poolax_img_tag( array(
								'url'   => esc_url( $settings['image2']['url'] ),
							));
						echo '</div>';
						echo '<div class="media-body">';
							if($settings['label2']){
								echo '<span class="footer-info_label">'.wp_kses_post($settings['label2']).'</span>';
							}
							if($settings['content2']){
								echo '<p class="footer-info_link content">'.wp_kses_post($settings['content2']).'</p>';
							}
						echo '</div>';
					echo '</div>';
				echo '</div>';
				echo '<div class="newletter-wrapper">';
					echo '<form class="newsletter-form">';
						echo '<input class="form-control" type="email" placeholder="'.esc_attr( $settings['newsletter_placeholder'] ).'" required="">';
						echo '<button type="submit" class="th-btn">'.wp_kses_post( $settings['newsletter_button'] ).'</button>';
					echo '</form>';
				echo '</div>';
			echo '</div>';

		}elseif( $settings['layout_style'] == '5' ){
			echo '<div class="newsletter-area2 bg overflow-hidden">';
				echo '<div class="newsletter-content">';
					echo '<div class="container">';
						echo '<div class="row gx-0 align-items-center">';
							if($settings['title']){
								echo '<div class="col-lg-6 col-xl-6">
									<div class="newsletter-wrapper style2">
										<h4 class="h4 newsletter-title title mb-0">'.wp_kses_post($settings['title']).'</h4>
									</div>
								</div>';
							}
							echo '<div class="col-lg-6 col-xl-6">';
								echo '<div class="newsletter-form-wrapper">';
									echo '<form class="newsletter-form">';
										echo '<input class="form-control" type="email" placeholder="'.esc_attr( $settings['newsletter_placeholder'] ).'" required="">';
										echo '<button type="submit" class="th-btn style3">'.wp_kses_post( $settings['newsletter_button'] ).'</button>';
									echo '</form>';
								echo '</div>';
							echo '</div>';
						echo '</div>';
					echo '</div>';
				echo '</div>';
				if(!empty($settings['shape']['url'])){
				echo '<div class="newsletter-shape">';
					echo poolax_img_tag( array(
						'url'   => esc_url( $settings['shape']['url'] ),
					));
				echo '</div>';
				}
				if(!empty($settings['shape2']['url'])){
				echo '<div class="newsletter-shape2">';
					echo poolax_img_tag( array(
						'url'   => esc_url( $settings['shape2']['url'] ),
					));
				echo '</div>';
				}
			echo '</div>';

		}elseif( $settings['layout_style'] == '6' ){
			echo '<div class="newsletter-content2 bg-theme bg">';
                echo '<div class="row gx-0 align-items-center">';
					if($settings['title']){
						echo '<div class="col-lg-6 col-xl-6">
							<div class="newsletter-wrapper">
								<h4 class="h4 newsletter-title title mb-0">'.wp_kses_post($settings['title']).'</h4>
							</div>
						</div>';
					}
                    echo '<div class="col-lg-6 col-xl-6">';
                        echo '<div class="newsletter-form-wrapper">';
                            echo '<form class="newsletter-form">';
								echo '<input class="form-control " type="email" placeholder="'.esc_attr( $settings['newsletter_placeholder'] ).'" required="">';
								echo '<button type="submit" class="th-btn style3">'.wp_kses_post( $settings['newsletter_button'] ).'</button>';
                            echo '</form>';
                        echo '</div>';
                    echo '</div>';
                echo '</div>';
            echo '</div>';

		}elseif( $settings['layout_style'] == '7' ){
			echo '<div>';
				echo '<div class="form-group newsletter-form style5">';
					echo '<input class="form-control" type="email" placeholder="'.esc_attr( $settings['newsletter_placeholder'] ).'" required="">';
					echo '<button type="submit" class="newsletter-btn">'.wp_kses_post( $settings['newsletter_button'] ).'</button>';
				echo '</div>';
			echo '</div>';

		}elseif( $settings['layout_style'] == '8' ){
			echo '<div class="newsletter-sec6 bg">';
				echo '<div class="newsletter-shape6" data-bg-src="'.esc_url($settings['bg']['url']).'"></div>';
				echo '<div class="container">';
					echo '<div class="row gx-0 align-items-center">';
						if($settings['title']){
							echo '<div class="col-lg-6">
								<div class="newsletter-wrapper">
									<h2 class="newsletter-title title mb-0">'.wp_kses_post($settings['title']).'</h2>
								</div>
							</div>';
						}
						echo '<div class="col-lg-6">';
							echo '<div class="newsletter-form-wrapper">';
								echo '<form class="newsletter-form">';
									echo '<input class="form-control " type="email" placeholder="'.esc_attr( $settings['newsletter_placeholder'] ).'" required="">';
									echo '<button type="submit" class="th-btn style3">'.wp_kses_post( $settings['newsletter_button'] ).'</button>';
								echo '</form>';
							echo '</div>';
						echo '</div>';
					echo '</div>';
				echo '</div>';
			echo '</div>';

		}else{
			echo '<div class="newsletter-area bg-theme bg">
				<div class="container">
					<div class="row gx-0 align-items-center">';
						if($settings['title']){
							echo '<div class="col-lg-6 col-xl-6">
								<div class="newsletter-wrapper">
									<h4 class="h4 newsletter-title text-white mb-0">'.wp_kses_post($settings['title']).'</h4>
								</div>
							</div>';
						}
						echo '<div class="col-lg-6 col-xl-6">
							<div class="newsletter-form-wrapper">
								<form class="newsletter-form">
									<input class="form-control " type="email" placeholder="'.esc_attr( $settings['newsletter_placeholder'] ).'" required="">
									<button type="submit" class="th-btn style3">'.wp_kses_post( $settings['newsletter_button'] ).'</button>
								</form>
							</div>
						</div>
					</div>
				</div>
			</div>';
		}
	

	}
}
						