<?php
use \Elementor\Widget_Base;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Typography;
use \Elementor\Utils;
use \Elementor\Group_Control_Image_Size;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Border;
use \Elementor\Repeater;
/**
 *
 * Price Widget .
 *
 */
class Poolax_Price extends Widget_Base {

	public function get_name() {
		return 'poolaxprice';
	}
	public function get_title() {
		return __( 'Price Box', 'poolax' );
	}
	public function get_icon() {
		return 'th-icon';
    }
	public function get_categories() {
		return [ 'poolax' ];
	}

	protected function register_controls() {

		$this->start_controls_section(
			'price_section',
			[
				'label' 	=> __( 'Price Box', 'poolax' ),
				'tab' 		=> Controls_Manager::TAB_CONTENT,
			]
        );

		$this->add_control(
			'layout_style',
			[
				'label' 	=> __( 'Layout Style', 'poolax' ),
				'type' 		=> Controls_Manager::SELECT,
				'default' 	=> '1',
				'options' 	=> [
					'1'  		=> __( 'Style One', 'poolax' ),
					'2'  		=> __( 'Style Two', 'poolax' ),
				],
			]
		);

		$repeater = new Repeater();
		
		poolax_general_fields($repeater, 'title', 'Title', 'TEXT', 'Basic Plan'); 
		poolax_general_fields($repeater, 'price', 'Price', 'TEXTAREA', '$120'); 
		poolax_code_fields($repeater, 'features', 'Features');
		poolax_general_fields($repeater, 'button_text', 'Button Text', 'TEXT', 'Button Text');
		poolax_url_fields($repeater, 'button_url', 'Button URL');

        $this->add_control(
			'price_list',
			[
				'label' 		=> __( 'Price List', 'poolax' ),
				'type' 			=> Controls_Manager::REPEATER,
				'fields' 		=> $repeater->get_controls(),
				'default' 		=> [
					[
						'title' 		=> __( 'Basic Plan', 'poolax' ),
					],
				],
			]
		);

		$this->end_controls_section();

        //---------------------------------------
			//Style Section Start
		//---------------------------------------

		//-------Title Style-------
		poolax_common_style_fields($this, 'title', 'Title', '{{WRAPPER}} .box-title');
		poolax_common_style_fields($this, 'desc', 'Description', '{{WRAPPER}} .price-box_desc', ['2']);
		//------Button Style-------
		poolax_button_style_fields($this, '11', 'Button Styling', '{{WRAPPER}} .th_btn');

	}

	protected function render() {

	$settings = $this->get_settings_for_display();

		if( $settings['layout_style'] == '2' ){
			echo '<div class="price-box_area">';
				echo '<div class="price-box-wrapper">';
					foreach( $settings['price_list'] as $data ){
						echo '<div class="price-box wow fadeInUp">';
							echo '<div class="price-box_wrapp">';
								echo '<div class="price-box_content">';
									if(!empty($data['title'])){
										echo '<h4 class="box-title"><a href="'.esc_url( $data['button_url']['url'] ).'">'.wp_kses_post($data['title']).'</a></h4>';
									}
									if(!empty($data['price'])){
										echo '<span class="price-box_price">'.wp_kses_post($data['price']).'</span>';
									}
								echo '</div>';
								echo '<p class="price-box_desc">';
									echo wp_kses_post($data['features']);
								echo '</p>';
								if(!empty($data['button_text'])){
									echo '<div class="price-btn mt-35">';
										echo '<a href="'.esc_url( $data['button_url']['url'] ).'" class="th-btn th_btn">'.wp_kses_post($data['button_text']).'</a>';
									echo '</div>';
								}
							echo '</div>';
						echo '</div>';
					}
				echo '</div>';
			echo '</div>';

		}else{
			echo '<div class="row gy-5 justify-content-center">';
				foreach( $settings['price_list'] as $data ){
					echo '<div class="col-xl-4 col-md-6">';
						echo '<div class="price-card ">';
							echo '<div class="price-card-wrapp">';
								if(!empty($data['price'])){
									echo '<div class="price-card_content">';
										echo '<h4 class="price-card_price">'.wp_kses_post($data['price']).'</h4>';
									echo '</div>';
								}
								if(!empty($data['title'])){
									echo '<h3 class="price-card_title box-title">'.esc_html($data['title']).'</h3>';
								}
							echo '</div>';
							echo '<div class="price-border"></div>';
							echo '<div class="available-list">';
								echo wp_kses_post($data['features']);
							echo '</div>';
							if(!empty($data['button_text'])){
								echo '<div class="price-btn mt-35">';
									echo '<a href="'.esc_url( $data['button_url']['url'] ).'" class="th-btn th_btn border radius-none">'.wp_kses_post($data['button_text']).'</a>';
								echo '</div>';
							}
						echo '</div>';
					echo '</div>';
				}
			echo '</div>';

		}


	}

}