<?php
use \Elementor\Widget_Base;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Typography;
use \Elementor\Utils;
use \Elementor\Group_Control_Image_Size;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Border;
use \Elementor\Repeater;
/**
 *
 * Step Widget .
 *
 */
class poolax_Step extends Widget_Base {

	public function get_name() {
		return 'poolaxstep';
	}
	public function get_title() {
		return __( 'Step/Process', 'poolax' );
	}
	public function get_icon() {
		return 'th-icon';
    }
	public function get_categories() {
		return [ 'poolax' ];
	}

	protected function register_controls() {

		 $this->start_controls_section(
			'section_title_section',
			[
				'label'		 	=> __( 'Steps', 'poolax' ),
				'tab' 			=> Controls_Manager::TAB_CONTENT,
			]
        );

		$this->add_control(
			'layout_style',
			[
				'label' 		=> __( 'Layout Style', 'poolax' ),
				'type' 			=> Controls_Manager::SELECT,
				'default' 		=> '1',
				'options' 		=> [
					'1'  		=> __( 'Style One', 'poolax' ),					
					'2'  		=> __( 'Style Two', 'poolax' ),					
					'3'  		=> __( 'Style Three', 'poolax' ),					
					'4'  		=> __( 'Style Four', 'poolax' ),					
					'5'  		=> __( 'Style Five', 'poolax' ),					
					'6'  		=> __( 'Style Six', 'poolax' ),					
				],
			]
		);

		poolax_media_fields($this, 'line_image', 'Choose Line Image', ['1', '5']);

		$repeater = new Repeater();

		poolax_general_fields($repeater, 'number', 'Number', 'TEXT', '01');
		poolax_general_fields($repeater, 'title', 'Title', 'TEXT', 'Initial Consultation');
		poolax_general_fields($repeater, 'desc', 'Description', 'TEXTAREA', '');
		poolax_media_fields($repeater, 'icon', 'Choose Icon');

		$this->add_control(
			'process_list',
			[
				'label' 		=> __( 'Process Lists', 'poolax' ),
				'type' 			=> Controls_Manager::REPEATER,
				'fields' 		=> $repeater->get_controls(),
				'default' 		=> [
					[
						'title'    => __( 'Initial Consultation', 'poolax' ),
					],
				],
				'condition'	=> [
					'layout_style' => [ '1', '3', '4', '5' ],
				]
			]
		);

		$repeater = new Repeater();

		poolax_general_fields($repeater, 'title', 'Title', 'TEXT', 'Surface Clean');
		poolax_general_fields($repeater, 'desc', 'Description', 'TEXTAREA', 'Brush the pool walls to them remove during the cleaning process.');
		poolax_media_fields($repeater, 'icon', 'Choose Icon');

		$this->add_control(
			'process_list2',
			[
				'label' 		=> __( 'Process Lists', 'poolax' ),
				'type' 			=> Controls_Manager::REPEATER,
				'fields' 		=> $repeater->get_controls(),
				'default' 		=> [
					[
						'title'    => __( 'Initial Consultation', 'poolax' ),
					],
				],
				'condition'	=> [
					'layout_style' => [ '2'],
				]
			]
		);

		$repeater = new Repeater();

		poolax_general_fields($repeater, 'number', 'Number', 'TEXT', '01');
		poolax_general_fields($repeater, 'title', 'Title', 'TEXT', 'Initial Consultation');
		poolax_general_fields($repeater, 'desc', 'Description', 'TEXTAREA', '');

		$this->add_control(
			'process_list3',
			[
				'label' 		=> __( 'Process Lists', 'poolax' ),
				'type' 			=> Controls_Manager::REPEATER,
				'fields' 		=> $repeater->get_controls(),
				'default' 		=> [
					[
						'title'    => __( 'Initial Consultation', 'poolax' ),
					],
				],
				'condition'	=> [
					'layout_style' => [ '6' ],
				]
			]
		);

        $this->end_controls_section();


        //---------------------------------------
			//Style Section Start
		//---------------------------------------
		
		//-------Title Style-------
		poolax_common_style_fields( $this, 'title', 'Title', '{{WRAPPER}} .th-title' );
		//-------Description Style-------
		poolax_common_style_fields( $this, 'desc', 'Description', '{{WRAPPER}} .th-desc' );
		

	}

	protected function render() {

	$settings = $this->get_settings_for_display(); 

		if( $settings['layout_style'] == '2' ){
			echo '<div class="row gy-5 justify-content-center justify-content-xl-between">';
				foreach( $settings['process_list2'] as $data ){
					echo '<div class="col-sm-6 col-lg-auto process-card-wrap">';
						echo '<div class="process-card3">';
							if(!empty($data['icon']['url'])){
								echo '<div class="process-card_icon">';
									echo poolax_img_tag( array(
										'url'   => esc_url( $data['icon']['url'] ),
									));
								echo '</div>';
							}
							if(!empty($data['title'])){
								echo '<h2 class="process-card_title th-title">'.esc_html($data['title']).'</h2>';
							}
							if(!empty($data['desc'])){
								echo '<p class="process-card_text th-desc">'.esc_html($data['desc']).'</p>';
							}
						echo '</div>';
					echo '</div>';
				}
			echo '</div>';

		}elseif( $settings['layout_style'] == '3' ){
			echo '<div class="row gy-5 justify-content-center">';
				foreach( $settings['process_list'] as $data ){
					echo '<div class="col-md-6 col-lg-4 process-box-wrap">';
						echo '<div class="process-box">';
							if(!empty($data['icon']['url'])){
								echo '<div class="process-box_img">';
									echo poolax_img_tag( array(
										'url'   => esc_url( $data['icon']['url'] ),
									));
								echo '</div>';
							}
							if(!empty($data['number'])){
								echo '<div class="process-box_icon">';
									echo '<span class="number">'.esc_html($data['number']).'</span>';
								echo '</div>';
							}
							echo '<div class="process-box_shape"></div>';
							echo '<div class="process-box_content">';
								if(!empty($data['title'])){
									echo '<h2 class="box-title th-title">'.esc_html($data['title']).'</h2>';
								}
								if(!empty($data['desc'])){
									echo '<p class="process-box_text th-desc">'.esc_html($data['desc']).'</p>';
								}
								echo '<div class="animation-bubble style3">
									<div class="bubble-1"></div>
									<div class="bubble-2"></div>
									<div class="bubble-3"></div>
									<div class="bubble-4"></div>
									<div class="bubble-5"></div>
									<div class="bubble-6"></div>
									<div class="bubble-7"></div>
									<div class="bubble-8"></div>
									<div class="bubble-9"></div>
									<div class="bubble-10"></div>
								</div>';
							echo '</div>';

						echo '</div>';
					echo '</div>';
				}
            echo '</div>';

		}elseif( $settings['layout_style'] == '4' ){
			echo '<div class="process-block_wrapp">';
				foreach( $settings['process_list'] as $data ){
					echo '<div class="process-block">';
						if(!empty($data['number'])){
							echo '<div class="process-block_icon">';
								echo '<span class="number">'.esc_html($data['number']).'</span>';
							echo '</div>';
						}
						echo '<div class="process-block_content">';
							if(!empty($data['title'])){
								echo '<h2 class="box-title th-title">'.esc_html($data['title']).'</h2>';
							}
							if(!empty($data['desc'])){
								echo '<p class="process-block_text th-desc">'.esc_html($data['desc']).'</p>';
							}
						echo '</div>';
						if(!empty($data['icon']['url'])){
							echo '<div class="process-block_img">';
								echo poolax_img_tag( array(
									'url'   => esc_url( $data['icon']['url'] ),
								));
							echo '</div>';
						}
					echo '</div>';
				}
            echo '</div>';

		}elseif( $settings['layout_style'] == '5' ){
			echo '<div class="step-wrap style3">';
				echo '<div class="process-line"></div>';
				echo '<div class="process-wrapper">';
					echo '<div class="process-card_wrapp style3">';
						foreach( $settings['process_list'] as $key => $data ){
							if ($key % 2 == 0) {
								echo '<div class="process-card style3">';
									if(!empty($data['number'])){
										echo '<div class="process-card_icon">';
											echo '<span class="number">'.esc_html($data['number']).'</span>';
										echo '</div>';
									}
									echo '<div class="process-card_content">';
										if(!empty($data['title'])){
											echo '<h2 class="box-title th-title">'.esc_html($data['title']).'</h2>';
										}
										if(!empty($data['desc'])){
											echo '<p class="process-card_text th-desc">'.esc_html($data['desc']).'</p>';
										}
									echo '</div>';
									if(!empty($data['icon']['url'])){
										echo '<div class="process-card_img">';
											echo poolax_img_tag( array(
												'url'   => esc_url( $data['icon']['url'] ),
											));
										echo '</div>';
									}
								echo '</div>';
							}
						}
					echo '</div>';
					if(!empty($settings['line_image']['url'])){
						echo '<div class="process-card_image">';
							echo poolax_img_tag( array(
								'url'   => esc_url( $settings['line_image']['url'] ),
							));
						echo '</div>';
					}
					echo '<div class="process-card_wrapp style3">';
						foreach( $settings['process_list'] as $key => $data ){
							if ($key % 2 != 0) {
								echo '<div class="process-card style3">';
									if(!empty($data['number'])){
										echo '<div class="process-card_icon">';
											echo '<span class="number">'.esc_html($data['number']).'</span>';
										echo '</div>';
									}
									echo '<div class="process-card_content">';
										if(!empty($data['title'])){
											echo '<h2 class="box-title th-title">'.esc_html($data['title']).'</h2>';
										}
										if(!empty($data['desc'])){
											echo '<p class="process-card_text th-desc">'.esc_html($data['desc']).'</p>';
										}
									echo '</div>';
									if(!empty($data['icon']['url'])){
										echo '<div class="process-card_img">';
											echo poolax_img_tag( array(
												'url'   => esc_url( $data['icon']['url'] ),
											));
										echo '</div>';
									}
								echo '</div>';
							}
						}
					echo '</div>';
				echo '</div>';
			echo '</div>';

		}elseif( $settings['layout_style'] == '6' ){
			foreach( $settings['process_list3'] as $data ){
				echo '<div class="process-item">';
					if(!empty($data['number'])){
						echo '<span class="process-item_number">'.esc_html($data['number']).'</span>';
					}
					if(!empty($data['title'])){
						echo '<h3 class="box-title th-title">'.wp_kses_post($data['title']).'</h3>';
					}
					if(!empty($data['desc'])){
						echo '<p class="mb-0 th-desc">'.esc_html($data['desc']).'</p>';
					}
				echo '</div>';
			}

		}else{
			echo '<div class="step-wrap">';
				if(!empty($settings['line_image']['url'])){
					echo '<div class="process-line">';
						echo poolax_img_tag( array(
							'url'   => esc_url( $settings['line_image']['url'] ),
						));
					echo '</div>';
				}
				echo '<div class="process-card_wrapp">';
					$x = 0;
					foreach( $settings['process_list'] as $data ){
						$x++;

						echo '<div class="process-card">';
							if(!empty($data['number'])){
								echo '<div class="process-card_icon">';
									echo '<span class="number">'.esc_html($data['number']).'</span>';
								echo '</div>';
							}
							echo '<div class="process-card_content">';
								if(!empty($data['title'])){
									echo '<h2 class="box-title th-title">'.esc_html($data['title']).'</h2>';
								}
								if(!empty($data['desc'])){
									echo '<p class="process-card_text th-desc">'.esc_html($data['desc']).'</p>';
								}
							echo '</div>';
							if(!empty($data['icon']['url'])){
								echo '<div class="process-card_img">';
									echo poolax_img_tag( array(
										'url'   => esc_url( $data['icon']['url'] ),
									));
								echo '</div>';
							}
						echo '</div>';
					}
				echo '</div>';
			echo '</div>';
		}
	

	}

}