<?php
use \Elementor\Widget_Base;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Typography;
use \Elementor\Utils;
use \Elementor\Repeater;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Image_Size;
/**
 *
 * Team Info Widget
 *
 */
class poolax_Team_info extends Widget_Base{

	public function get_name() {
		return 'poolaxteaminfo';
	}
	public function get_title() {
		return esc_html__( 'Team Member Info', 'poolax' );
	}
	public function get_icon() {
		return 'th-icon';
    }
	public function get_categories() {
		return [ 'poolax' ];
	}

	protected function register_controls() {

		$this->start_controls_section(
			'team_member_content',
			[
				'label'		=> esc_html__( 'Member Info','poolax' ),
				'tab'		=> Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'layout_style',
			[
				'label' 		=> __( 'Layout Style', 'poolax' ),
				'type' 			=> Controls_Manager::SELECT,
				'default' 		=> '1',
				'options'		=> [
					'1'  			=> __( 'Style One', 'poolax' ),
				],
			]
		);

		poolax_general_fields($this, 'name', 'Member Name', 'TEXT', 'Jonson Anderson');
		poolax_general_fields($this, 'designation', 'Designation', 'TEXT', 'Pool Technician');
		poolax_general_fields($this, 'desc', 'Description', 'TEXTAREA', ''); 

		poolax_social_fields($this, 'social_icon_list', 'Social Media');

		$repeater = new Repeater();

		poolax_general_fields($repeater, 'label', 'Label', 'TEXT', 'Experience');
		poolax_general_fields($repeater, 'content', 'Content', 'TEXTAREA', '22 Years');

		$this->add_control(
			'feature_lists',
			[
				'label' 		=> __( 'Feature Lists', 'poolax' ),
				'type' 			=> Controls_Manager::REPEATER,
				'fields' 		=> $repeater->get_controls(),
				'default' 		=> [
						[
							'label' 		=> __( 'Experience', 'poolax' ),
						],
				],
			]
		);

		$this->end_controls_section();


        //---------------------------------------
			//Style Section Start
		//---------------------------------------

		//-------Title Style-------
		poolax_common_style_fields($this, 'name', 'Name', '{{WRAPPER}} .about-card_title');
		//-------Designation Style-------
		poolax_common_style_fields($this, 'designation', 'Designation', '{{WRAPPER}} .about-card_desig', '', '--theme-color');
		//-------Description Style-------
		poolax_common_style_fields($this, 'desc', 'Description', '{{WRAPPER}} .about-card_text');


	}

	protected function render() {

	$settings = $this->get_settings_for_display(); 

		if( $settings['layout_style'] == '2' ){

		}else{
			echo '<div class="about-card">';
				echo '<div class="about-card_content">';
					echo '<h2 class="about-card_title">'.esc_html($settings['name']).'</h2>';
					echo '<p class="about-card_desig text-theme">'.esc_html($settings['designation']).'</p>';
					echo '<div class="th-social">';
						foreach( $settings['social_icon_list'] as $social_icon ){
							$social_target    = $social_icon['icon_link']['is_external'] ? ' target="_blank"' : '';
							$social_nofollow  = $social_icon['icon_link']['nofollow'] ? ' rel="nofollow"' : '';

							echo '<a '.wp_kses_post( $social_target.$social_nofollow ).' href="'.esc_url( $social_icon['icon_link']['url'] ).'">';

							\Elementor\Icons_Manager::render_icon( $social_icon['social_icon'], [ 'aria-hidden' => 'true' ] );

							echo '</a> ';
						}
					echo '</div>';
					echo '<p class="about-card_text">'.wp_kses_post($settings['desc']).'</p>';

					echo '<div class="team-info">';
						echo '<ul>';
							foreach( $settings['feature_lists'] as $data ){
								echo '<li><b>'.esc_html($data['label']).'</b> '.wp_kses_post($data['content']).'</li>';
							}
						echo '</ul>';
					echo '</div>';
				echo '</div>';
			echo '</div>';

		}
		
	}
}